@@ -224,9 +224,13 @@ void MainWindow::updateConfigFileName(const QString &fileName)
 
 void MainWindow::loadConfigFromFile(const QString & fileName)
 {
-  m_expert->loadConfig(fileName);
-  m_wizard->refresh();
+  // save full path info of original file
+  QString absFileName = QFileInfo(fileName).absoluteFilePath();
+  // updates the current directory
   updateConfigFileName(fileName);
+  // open the specified configuration file
+  m_expert->loadConfig(absFileName);
+  m_wizard->refresh();
   updateLaunchButtonState();
   m_modified = false;
   updateTitle();
@@ -483,7 +487,7 @@ void MainWindow::readStdout()
   if (m_running)
   {
     QByteArray data = m_runProcess->readAllStandardOutput();
-    QString text = QString::fromLocal8Bit(data);
+    QString text = QString::fromUtf8(data);
     if (!text.isEmpty())
     {
       m_outputLog->append(text.trimmed());
@@ -525,7 +529,7 @@ void MainWindow::showHtmlOutput()
   // TODO: the following doesn't seem to work with IE
 #ifdef WIN32
   //QString indexUrl(QString::fromAscii("file:///"));
-  ShellExecute(NULL, L"open", fi.absoluteFilePath().utf16(), NULL, NULL, SW_SHOWNORMAL);
+  ShellExecute(NULL, L"open", (LPCWSTR)fi.absoluteFilePath().utf16(), NULL, NULL, SW_SHOWNORMAL);
 #else
   QString indexUrl(QString::fromAscii("file://"));
   indexUrl+=fi.absoluteFilePath();
