@@ -16,9 +16,7 @@
   Originally, the script was written in Perl and was known as translator.pl.
   The last Perl version was dated 2002/05/21 (plus some later corrections)
 
-  $Id: translator.py 744 2010-10-09 08:04:33Z dimitri $
-
-                                         Petr Prikryl (prikrylp@skil.cz)
+                                         Petr Prikryl (prikryl at atlas dot cz)
 
   History:
   --------
@@ -63,6 +61,9 @@
   2010/09/27 - The underscore in \latexonly part of the generated language.doc
                was prefixed by backslash (was LaTeX related error).
   2013/02/19 - Better diagnostics when translator_xx.h is too crippled.
+  2013/06/25 - TranslatorDecoder checks removed after removing the class.
+  2013/09/04 - Coloured status in langhowto. *ALMOST up-to-date* category
+               of translators introduced.
   """
 
 from __future__ import generators
@@ -187,7 +188,6 @@ class Transl:
         self.missingMethods = None   # list of prototypes to be implemented
         self.implementedMethods = None  # list of implemented required methods
         self.adaptMinClass = None    # The newest adapter class that can be used
-        self.isDecodedTranslator = None  # Flag related to internal usage of UTF-8
 
     def __tokenGenerator(self):
         """Generator that reads the file and yields tokens as 4-tuples.
@@ -1119,20 +1119,13 @@ class Transl:
             else:
                 self.missingMethods.append(p)
 
-        # Set the least important note first if the translator is decoded.
-        # If yes, then it means that the implementation should be switched
-        # to UTF-8 later (suggestion).
-        self.isDecodedTranslator = self.classId in self.manager.decodedTranslators
-        if self.isDecodedTranslator:
-            self.note = 'Reimplementation using UTF-8 suggested.'
-
         # Check whether adapter must be used or suggest the newest one.
         # Change the status and set the note accordingly.
         if self.baseClassId != 'Translator':
             if not self.missingMethods:
                 self.note = 'Change the base class to Translator.'
                 self.status = ''
-                self.readableStatus = 'up-to-date'
+                self.readableStatus = 'almost up-to-date'
             elif self.baseClassId != 'TranslatorEnglish':
                 # The translator uses some of the adapters.
                 # Look at the missing methods and check what adapter
@@ -1170,7 +1163,7 @@ class Transl:
            if self.note != '':
                self.note += '\n\t\t'
            if self.txtMAX_DOT_GRAPH_HEIGHT_flag:
-                self.note += 'The MAX_DOT_GRAPH_HEIGHT found in trLegendDocs()'
+               self.note += 'The MAX_DOT_GRAPH_HEIGHT found in trLegendDocs()'
 
         # If everything seems OK, but there are obsolete methods, set
         # the note to clean-up source. This note will be used only when
@@ -1178,6 +1171,11 @@ class Transl:
         if not self.note and self.status == '' and self.obsoleteMethods:
             self.note = 'Remove the obsolete methods (never used).'
 
+        # If there is at least some note but the status suggests it is
+        # otherwise up-to-date, mark is as ALMOST up-to-date.
+        if self.note and self.status == '':
+            self.readableStatus = 'almost up-to-date'
+
 
     def report(self, fout):
         """Returns the report part for the source as a multiline string.
@@ -1309,44 +1307,10 @@ class TrManager:
         self.numLang = None                   # excluding coupled En-based
         self.doxVersion = None                # Doxygen version
 
-        # Capture the knowledge about translators that are not implemented
-        # to use UTF-8 internally.
-        self.decodedTranslators = self.getDecodedTranslators()
-
         # Build objects where each one is responsible for one translator.
         self.__build()
 
 
-    def getDecodedTranslators(self):
-        """Parses language.cpp to find what translators do not use UTF-8 yet"""
-        decodedTranslators = []
-
-        # Regular expression to detect the lines like
-        #     theTranslator=new TranslatorDecoder(new TranslatorSwedish);
-        rex = re.compile(r'^\s*theTranslator\s*=\s*new\s+.*$')
-
-        # Regular expression to get the (optional) TranslatorDecoder and TranslatorXXX
-        rex2 = re.compile(r'\bTranslator\w+')
-
-        # Parse the lines in the specific source code.
-        f = open(os.path.join(self.src_path, 'language.cpp'), 'rU')
-        for line in f:
-            if rex.match(line):
-                lst = rex2.findall(line)
-                if lst[0] == 'TranslatorDecoder':
-                    decodedTranslators.append(lst[1])
-        f.close()
-
-        # Display warning when all translator implementations were converted
-        # to UTF-8.
-        if len(decodedTranslators) == 0:
-            print 'This script should be updated. All translators do use UTF-8'
-            print 'internally.  The TranslatorDecoder adapter should be removed'
-            print 'from the code and its usage should not be checked any more.'
-
-        return decodedTranslators
-
-
     def __build(self):
         """Find the translator files and build the objects for translators."""
 
@@ -1565,6 +1529,24 @@ class TrManager:
         return lst
 
 
+    def getBgcolorByReadableStatus(self, readableStatus):
+        if readableStatus == 'up-to-date':
+            color = '#ccffcc'    # green
+        elif readableStatus.startswith('almost'):
+            color = '#ffffff'    # white
+        elif readableStatus.startswith('English'):
+            color = '#ccffcc'    # green
+        elif readableStatus.startswith('1.8'):
+            color = '#ffffcc'    # yellow
+        elif readableStatus.startswith('1.7'):
+            color = '#ffcccc'    # pink
+        elif readableStatus.startswith('1.6'):
+            color = '#ffcccc'    # pink
+        else:
+            color = '#ff5555'    # red
+        return color
+
+
     def generateTranslatorReport(self):
         """Generates the translator report."""
 
@@ -1601,13 +1583,12 @@ class TrManager:
         # in the translator report.
         fmail = open('mailto.txt', 'w')
 
-        # Write the list of up-to-date translator classes.
+        # Write the list of "up-to-date" translator classes.
         if self.upToDateIdLst:
             s = '''The following translator classes are up-to-date (sorted
                 alphabetically). This means that they derive from the
-                Translator class and they implement all %d of the required
-                methods. Anyway, there still may be some details listed even
-                for them:'''
+                Translator class, they implement all %d of the required
+                methods, and even minor problems were not spotted by the script:'''
             s = s % len(self.requiredMethodsDic)
             f.write('-' * 70 + '\n')
             f.write(fill(s) + '\n\n')
@@ -1615,19 +1596,35 @@ class TrManager:
             mailtoLst = []
             for x in self.upToDateIdLst:
                 obj = self.__translDic[x]
-                f.write('  ' + obj.classId)
-                if obj.note:
-                    f.write(' -- ' + obj.note)
-                f.write('\n')
-                mailtoLst.extend(self.__emails(obj.classId))
+                if obj.note is None:
+                    f.write('  ' + obj.classId + '\n')
+                    mailtoLst.extend(self.__emails(obj.classId))
 
             fmail.write('up-to-date\n')
             fmail.write('; '.join(mailtoLst))
 
+
+            # Write separately the list of "ALMOST up-to-date" translator classes.
+            s = '''The following translator classes are ALMOST up-to-date (sorted
+                alphabetically). This means that they derive from the
+                Translator class, but there still may be some minor problems
+                listed for them:'''
+            f.write('\n' + ('-' * 70) + '\n')
+            f.write(fill(s) + '\n\n')
+            mailtoLst = []
+            for x in self.upToDateIdLst:
+                obj = self.__translDic[x]
+                if obj.note is not None:
+                    f.write('  ' + obj.classId + '\t-- ' + obj.note + '\n')
+                    mailtoLst.extend(self.__emails(obj.classId))
+
+            fmail.write('\n\nalmost up-to-date\n')
+            fmail.write('; '.join(mailtoLst))
+
         # Write the list of the adapter based classes. The very obsolete
         # translators that derive from TranslatorEnglish are included.
         if self.adaptIdLst:
-            s = '''The following translator classes need some maintenance
+            s = '''The following translator classes need maintenance
                 (the most obsolete at the end). The other info shows the
                 estimation of Doxygen version when the class was last
                 updated and number of methods that must be implemented to
@@ -1832,7 +1829,7 @@ class TrManager:
         # document template.
         tplDic = {}
 
-        s = u'Do not edit this file. It was generated by the %s script.' % self.script_name
+        s = u'Do not edit this file. It was generated by the %s script.\n * Instead edit %s and %s' % (self.script_name, self.languageTplFileName, self.maintainersFileName)
         tplDic['editnote'] = s
 
         tplDic['doxVersion'] = self.doxVersion
@@ -1871,14 +1868,22 @@ class TrManager:
         htmlTableTpl = dedent(htmlTableTpl)
         htmlTrTpl = u'\n  <tr bgcolor="#ffffff">%s\n  </tr>'
         htmlTdTpl = u'\n    <td>%s</td>'
+        htmlTdStatusColorTpl = u'\n    <td bgcolor="%s">%s</td>'
 
         # Loop through transl objects in the order of sorted readable names
         # and add generate the content of the HTML table.
         trlst = []
         for name, obj in self.langLst:
             # Fill the table data elements for one row. The first element
-            # contains the readable name of the language.
-            lst = [ htmlTdTpl % obj.langReadable ]
+            # contains the readable name of the language. Only the oldest
+            # translator are colour marked in the language columnt. Less
+            # "heavy" color is used (when compared with the Status column).
+            if obj.readableStatus.startswith('1.4'):
+                bkcolor = self.getBgcolorByReadableStatus('1.4')
+            else:
+                bkcolor = '#ffffff'
+
+            lst = [ htmlTdStatusColorTpl % (bkcolor, obj.langReadable) ]
 
             # The next two elements contain the list of maintainers
             # and the list of their mangled e-mails. For English-based
@@ -1925,7 +1930,8 @@ class TrManager:
             lst.append(htmlTdTpl % ee)
 
             # The last element contains the readable form of the status.
-            lst.append(htmlTdTpl % obj.readableStatus)
+            bgcolor = self.getBgcolorByReadableStatus(obj.readableStatus)
+            lst.append(htmlTdStatusColorTpl % (bgcolor, obj.readableStatus))
 
             # Join the table data to one table row.
             trlst.append(htmlTrTpl % (''.join(lst)))
