@@ -92,16 +92,17 @@ int QGDict::hashKeyString( const QString &key )
     int i;
     register uint h=0;
     uint g;
+    int len = key.length();
     const QChar *p = key.unicode();
     if ( cases ) {				// case sensitive
-	for ( i=0; i<(int)key.length(); i++ ) {
+	for ( i=0; i<len; i++ ) {
 	    h = (h<<4) + p[i].cell();
 	    if ( (g = h & 0xf0000000) )
 		h ^= g >> 24;
 	    h &= ~g;
 	}
     } else {					// case insensitive
-	for ( i=0; i<(int)key.length(); i++ ) {
+	for ( i=0; i<len; i++ ) {
 	    h = (h<<4) + p[i].lower().cell();
 	    if ( (g = h & 0xf0000000) )
 		h ^= g >> 24;
@@ -123,7 +124,10 @@ int QGDict::hashKeyAscii( const char *key )
 {
 #if defined(CHECK_NULL)
     if ( key == 0 )
+    {
 	qWarning( "QGDict::hashAsciiKey: Invalid null key" );
+        return 0;
+    }
 #endif
     register const char *k = key;
     register uint h=0;
@@ -462,7 +466,7 @@ QCollection::Item QGDict::look_int( long key, QCollection::Item d, int op )
 QCollection::Item QGDict::look_ptr( void *key, QCollection::Item d, int op )
 {
     QPtrBucket *n;
-    int index = (int)((ulong)key % vlen);	// simple hash
+    int index = (int)((uintptr_t)key % vlen);	// simple hash
     if ( op == op_find ) {			// find
 	for ( n=(QPtrBucket*)vec[index]; n;
 	      n=(QPtrBucket*)n->getNext() ) {
@@ -677,7 +681,7 @@ QPtrBucket *QGDict::unlink_ptr( void *key, QCollection::Item d )
 	return 0;
     QPtrBucket *n;
     QPtrBucket *prev = 0;
-    int index = (int)((ulong)key % vlen);
+    int index = (int)((uintptr_t)key % vlen);
     for ( n=(QPtrBucket *)vec[index]; n; n=(QPtrBucket *)n->getNext() ) {
 	bool found = (n->getKey() == key);
 	if ( found && d )
@@ -903,11 +907,11 @@ void QGDict::statistics() const
     QString line;
     line.fill( '-', 60 );
     double real, ideal;
-    qDebug( line.ascii() );
+    qDebug( "%s",line.ascii() );
     qDebug( "DICTIONARY STATISTICS:" );
     if ( count() == 0 ) {
 	qDebug( "Empty!" );
-	qDebug( line.ascii() );
+	qDebug( "%s", line.ascii() );
 	return;
     }
     real = 0.0;
@@ -928,7 +932,7 @@ void QGDict::statistics() const
 	while ( b-- )
 	    *pbuf++ = '*';
 	*pbuf = '\0';
-	qDebug( buf );
+	qDebug( "%s", buf );
 	i++;
     }
     qDebug( "Array size = %d", size() );
@@ -936,7 +940,7 @@ void QGDict::statistics() const
     qDebug( "Real dist  = %g", real );
     qDebug( "Rand dist  = %g", ideal );
     qDebug( "Real/Rand  = %g", real/ideal );
-    qDebug( line.ascii() );
+    qDebug( "%s",line.ascii() );
 #endif // DEBUG
 }
 
@@ -1008,7 +1012,7 @@ QDataStream &QGDict::read( QDataStream &s )
 		    // but hey, serializing pointers?  can it be done
 		    // at all, ever?
 		    if ( k )
-			look_ptr( (void *)k, d, op_insert );
+			look_ptr( (void *)(uintptr_t)k, d, op_insert );
 		}
 		break;
 	}
