@@ -308,7 +308,7 @@ bool QStringBuffer::open( int m )
 	s->truncate( 0 );
     }
     if ( m & IO_Append ) {                      // append to end of buffer
-	ioIndex = s->length()*sizeof(QChar);
+	ioIndex = s->length()*(int)sizeof(QChar);
     } else {
 	ioIndex = 0;
     }
@@ -331,7 +331,7 @@ void QStringBuffer::flush()
 
 uint QStringBuffer::size() const
 {
-    return s ? s->length()*sizeof(QChar) : 0;
+    return s ? s->length()*(int)sizeof(QChar) : 0;
 }
 
 int  QStringBuffer::at()   const
@@ -553,7 +553,7 @@ QTextStream::QTextStream( QByteArray a, int mode )
     dev = new QBuffer( a );
     ((QBuffer *)dev)->open( mode );
     owndev = TRUE;
-    setEncoding( Latin1 ); //### Locale???
+    setEncoding( Locale ); //### Locale???
     reset();
     d->sourceType = QTextStreamPrivate::ByteArray;
 }
@@ -916,7 +916,7 @@ QTextStream &QTextStream::writeBlock( const char* p, uint len )
 	QChar *u = new QChar[len];
 	for (uint i=0; i<len; i++)
 	    u[i] = p[i];
-	dev->writeBlock( (char*)u, len*sizeof(QChar) );
+	dev->writeBlock( (char*)u, len*(int)sizeof(QChar) );
 	delete [] u;
     } else {
 	for (uint i=0; i<len; i++)
@@ -932,7 +932,7 @@ QTextStream &QTextStream::writeBlock( const QChar* p, uint len )
 	    doUnicodeHeader = FALSE;
 	    ts_putc( QChar::byteOrderMark );
 	}
-	dev->writeBlock( (char*)p, sizeof(QChar)*len );
+	dev->writeBlock( (char*)p, (int)sizeof(QChar)*len );
     } else {
 	for (uint i=0; i<len; i++)
 	    ts_putc( p[i] );
@@ -1894,7 +1894,7 @@ QTextStream &QTextStream::operator<<( void *ptr )
     setf( hex, basefield );
     setf( showbase );
     unsetf( uppercase );
-    output_int( I_LONG | I_UNSIGNED, (ulong)ptr, FALSE );
+    output_int( I_LONG | I_UNSIGNED, (uintptr_t)ptr, FALSE );
     flags( f );
     return *this;
 }
