@@ -26,11 +26,11 @@
 //--------------------------------------------------------------------------
 
 static const char *doxygen_bst =
-#include "doxygen_bst.h"
+#include "doxygen.bst.h"
 ;
 
 static const char *bib2xhtml_pl =
-#include "bib2xhtml.h"
+#include "bib2xhtml.pl.h"
 ;
 
 //--------------------------------------------------------------------------
@@ -88,11 +88,24 @@ static QCString getListOfBibFiles(const QCString &sep,bool namesOnly)
 
 void CiteDict::writeLatexBibliography(FTextStream &t)
 {
-  if (m_entries.count()==0) return;
+  if (m_entries.isEmpty())
+    return;
+
   QCString style = Config_getString("LATEX_BIB_STYLE");
-  if (style.isEmpty()) style="plain";
-  t << "\\newpage \\bibliographystyle{" << style << "}" << endl;
-  t << "\\bibliography{" << getListOfBibFiles(",",TRUE) << "}" << endl;
+  if (style.isEmpty())
+    style="plain";
+  QCString unit;
+  if (Config_getBool("COMPACT_LATEX"))
+    unit = "section";
+  else
+    unit = "chapter";
+  t << "% Bibliography\n"
+       "\\newpage\n"
+       "\\phantomsection\n"
+       "\\addcontentsline{toc}{" << unit << "}{" << theTranslator->trCiteReferences() << "}\n"
+       "\\bibliographystyle{" << style << "}\n"
+       "\\bibliography{" << getListOfBibFiles(",",TRUE) << "}\n"
+       "\n";
 }
 
 void CiteDict::insert(const char *label)
@@ -130,7 +143,7 @@ void CiteDict::generatePage() const
   f.setName(citeListFile);
   if (!f.open(IO_WriteOnly)) 
   {
-    err("error: could not open file %s for writing\n",citeListFile.data());
+    err("could not open file %s for writing\n",citeListFile.data());
   }
   FTextStream t(&f);
   t << "<!-- BEGIN CITATIONS -->" << endl;
@@ -153,7 +166,7 @@ void CiteDict::generatePage() const
   QCString bib2xhtml = bib2xhtml_pl;
   if (!f.open(IO_WriteOnly)) 
   {
-    err("error: could not open file %s for writing\n",bib2xhtmlFile.data());
+    err("could not open file %s for writing\n",bib2xhtmlFile.data());
   }
   f.writeBlock(bib2xhtml, bib2xhtml.length());
   f.close();
@@ -164,7 +177,7 @@ void CiteDict::generatePage() const
   f.setName(doxygenBstFile);
   if (!f.open(IO_WriteOnly)) 
   {
-    err("error: could not open file %s for writing\n",doxygenBstFile.data());
+    err("could not open file %s for writing\n",doxygenBstFile.data());
   }
   f.writeBlock(bstData, bstData.length());
   f.close();
@@ -198,7 +211,7 @@ void CiteDict::generatePage() const
       }
       else if (!fi.exists())
       {
-        err("Error: bib file %s not found!\n",bibFile.data());
+        err("bib file %s not found!\n",bibFile.data());
       }
       bibdata = citeDataList.next();
     }
@@ -218,7 +231,7 @@ void CiteDict::generatePage() const
   f.setName(citeListFile);
   if (!f.open(IO_ReadOnly)) 
   {
-    err("error: could not open file %s/citelist.doc for reading\n",outputDir.data());
+    err("could not open file %s/citelist.doc for reading\n",outputDir.data());
   }
   bool insideBib=FALSE;
   
@@ -285,7 +298,7 @@ void CiteDict::generatePage() const
       }
       else
       {
-        err("Error: bib file %s not found!\n",bibFile.data());
+        err("bib file %s not found!\n",bibFile.data());
       }
       bibdata = citeDataList.next();
     }
