@@ -129,6 +129,12 @@ CommandMap cmdMap[] =
   { "rtfonly",       CMD_RTFONLY },
   { "endrtfonly",    CMD_ENDRTFONLY },
   { "vhdlflow",      CMD_VHDLFLOW },
+  { "docbookonly",   CMD_DBONLY },
+  { "enddocbookonly",CMD_ENDDBONLY },
+  { "endinternal",   CMD_ENDINTERNAL },
+  { "parblock",      CMD_PARBLOCK },
+  { "endparblock",   CMD_ENDPARBLOCK },
+  { "diafile",       CMD_DIAFILE },
   { 0,               0 },
 };
 
