@@ -120,7 +120,11 @@ enum CommandType
   CMD_PIPE         = 90,
   CMD_VHDLFLOW     = 91,
   CMD_DBONLY       = 92,
-  CMD_ENDDBONLY    = 93
+  CMD_ENDDBONLY    = 93,
+  CMD_ENDINTERNAL  = 94,
+  CMD_PARBLOCK     = 95,
+  CMD_ENDPARBLOCK  = 96,
+  CMD_DIAFILE      = 97
 };
 
 enum HtmlTagType
