@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: code.h,v 1.9 2001/03/19 19:27:39 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -18,6 +18,8 @@
 #ifndef CODE_H
 #define CODE_H
 
+#include "types.h"
+
 class CodeOutputInterface;
 class FileDef;
 class MemberDef;
@@ -25,9 +27,10 @@ class QCString;
 class Definition;
 
 void parseCCode(CodeOutputInterface &,const char *,const QCString &, 
-            bool ,const char *,FileDef *fd,
+            SrcLangExt lang, bool isExample, const char *exName,FileDef *fd,
             int startLine,int endLine,bool inlineFragment,
-            MemberDef *memberDef,bool showLineNumbers,Definition *searchCtx);
+            MemberDef *memberDef,bool showLineNumbers,Definition *searchCtx,
+            bool collectXRefs);
 void resetCCodeParserState();
 void codeFreeScanner();
 
