@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: constexp.h,v 1.6 2001/03/19 19:27:40 root Exp $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -22,9 +22,9 @@
 #include "cppvalue.h"
 #include <qcstring.h>
 
-extern bool parseCppExpression(const char *fileName,int line,const QCString &s);
-extern int cppExpYYparse();
-extern int cppExpYYdebug;
+extern bool parseconstexp(const char *fileName,int line,const QCString &s);
+extern int constexpYYparse();
+extern int constexpYYdebug;
 extern QCString g_strToken;
 extern CPPValue g_resultValue;
 extern QCString g_constExpFileName;
