@@ -861,6 +861,7 @@ bool DBusXMLScanner::needsPreprocessing(const QCString & /* extension */)
 void DBusXMLScanner::parseCode(CodeOutputInterface & /* codeOutIntf */,
                                const char * /* scopeName */,
                                const QCString & /* input */,
+                               SrcLangExt /* lang */,
                                bool /* isExampleBlock */,
                                const char * /* exampleName */,
                                FileDef * /* fileDef */,
@@ -869,7 +870,8 @@ void DBusXMLScanner::parseCode(CodeOutputInterface & /* codeOutIntf */,
                                bool /* inlineFragment */,
                                MemberDef * /* memberDef */,
                                bool /*showLineNumbers*/,
-                               Definition * /* searchCtx */)
+                               Definition * /* searchCtx */,
+                               bool /*collectXRefs*/ )
 { }
 
 void DBusXMLScanner::resetCodeParserState()
