@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: debug.cpp,v 1.7 2001/03/19 19:27:40 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -21,6 +21,7 @@
 #include <qdict.h>
 
 #include "debug.h"
+#include "message.h"
 
 //------------------------------------------------------------------------
 
@@ -46,6 +47,7 @@ static LabelMap s_labels[] =
   { "extcmd",       Debug::ExtCmd       },
   { "markdown",     Debug::Markdown     },
   { "filteroutput", Debug::FilterOutput },
+  { "lex",          Debug::Lex },
   { 0,             (Debug::DebugMask)0  }
 };
 
@@ -97,9 +99,11 @@ static int labelToEnumValue(const char *l)
   if (event) return *event; else return 0;
 }
 
-void Debug::setFlag(const char *lab)
+int Debug::setFlag(const char *lab)
 {
+  int retVal = labelToEnumValue(lab);
   curMask = (DebugMask)(curMask | labelToEnumValue(lab));   
+  return retVal;
 }
 
 void Debug::clearFlag(const char *lab)
@@ -117,3 +121,14 @@ bool Debug::isFlagSet(DebugMask mask)
   return (curMask & mask)!=0;
 }
 
+void Debug::printFlags(void)
+{
+  int i;
+  for (i = 0; i < (int)(sizeof(s_labels)/sizeof(*s_labels)); i++)
+  {
+     if (s_labels[i].name)
+     {
+        msg("\t%s\n",s_labels[i].name);
+     }
+  }
+}
