@@ -1,6 +1,6 @@
 /******************************************************************************
 *
-* $Id: docbookgen.cpp,v 1.0 2012/11/15 10:15:10 root Exp $
+* 
 *
 * Copyright (C) 1997-2012 by Dimitri van Heesch.
 *
@@ -57,13 +57,13 @@
 //------------------
 
 static const char index_xsd[] =
-#include "index_xsd.h"
+#include "index.xsd.h"
 ;
 
 //------------------
 //
 static const char compound_xsd[] =
-#include "compound_xsd.h"
+#include "compound.xsd.h"
 ;
 
 //------------------
@@ -191,8 +191,7 @@ class DocbookCodeGenerator : public CodeOutputInterface
 {
   public:
     DocbookCodeGenerator(FTextStream &t) : m_t(t), m_lineNumber(-1),
-    m_insideCodeLine(FALSE), m_normalHLNeedStartTag(TRUE),
-    m_insideSpecialHL(FALSE) {}
+    m_insideCodeLine(FALSE), m_insideSpecialHL(FALSE) {}
     virtual ~DocbookCodeGenerator() {}
 
     void codify(const char *text)
@@ -208,6 +207,12 @@ class DocbookCodeGenerator : public CodeOutputInterface
       writeDocbookLink(m_t,ref,file,anchor,name,tooltip);
       col+=strlen(name);
     }
+    void writeTooltip(const char *, const DocLinkInfo &, const char *,
+                      const char *, const SourceLinkInfo &, const SourceLinkInfo &
+                     )
+    {
+      Docbook_DB(("(writeToolTip)\n"));
+    }
     void startCodeLine(bool)
     {
       Docbook_DB(("(startCodeLine)\n"));
@@ -235,16 +240,6 @@ class DocbookCodeGenerator : public CodeOutputInterface
       m_external.resize(0);
       m_insideCodeLine=FALSE;
     }
-    void startCodeAnchor(const char *id)
-    {
-      Docbook_DB(("(startCodeAnchor)\n"));
-      m_t << "<anchor id=\"" << id << "\">";
-    }
-    void endCodeAnchor()
-    {
-      Docbook_DB(("(endCodeAnchor)\n"));
-      m_t << "</anchor>";
-    }
     void startFontClass(const char * /*colorClass*/)
     {
       Docbook_DB(("(startFontClass)\n"));
@@ -295,7 +290,6 @@ class DocbookCodeGenerator : public CodeOutputInterface
     bool m_isMemberRef;
     int col;
     bool m_insideCodeLine;
-    bool m_normalHLNeedStartTag;
     bool m_insideSpecialHL;
 };
 
@@ -370,11 +364,13 @@ static void writeDocbookDocBlock(FTextStream &t,
 void writeDocbookCodeBlock(FTextStream &t,FileDef *fd)
 {
   ParserInterface *pIntf=Doxygen::parserManager->getParser(fd->getDefFileExtension());
+  SrcLangExt langExt = getLanguageFromFileName(fd->getDefFileExtension());
   pIntf->resetCodeParserState();
   DocbookCodeGenerator *docbookGen = new DocbookCodeGenerator(t);
   pIntf->parseCode(*docbookGen,  // codeOutIntf
       0,           // scopeName
       fileToString(fd->absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
+      langExt,     // lang
       FALSE,       // isExampleBlock
       0,           // exampleName
       fd,          // fileDef
@@ -1171,7 +1167,27 @@ static void generateDocbookForClass(ClassDef *cd,FTextStream &ti)
       {
         t << "<link linkend=\"" << ii->fileDef->getOutputFileBase() << "\">";
       }
-      t << "&lt;" << nm << "&gt;" << "</link>";
+      if (ii->local)
+      {
+        t << "&quot;";
+      }
+      else
+      {
+        t << "&lt;";
+      }
+      t << convertToXML(nm);
+      if (ii->local)
+      {
+        t << "&quot;";
+      }
+      else
+      {
+        t << "&gt;";
+      }
+      if (ii->fileDef && !ii->fileDef->isReference())
+      {
+        t << "</link>";
+      }
       t << "</programlisting>" << endl;
       t << "</para>" << endl;
     }
@@ -1389,7 +1405,23 @@ static void generateDocbookForFile(FileDef *fd,FTextStream &ti)
     for (ili1.toFirst();(inc=ili1.current());++ili1)
     {
       t << "    <programlisting>#include ";
-      t << inc->includeName;
+      if (inc->local)
+      {
+        t << "&quot;";
+      }
+      else
+      {
+        t << "&lt;";
+      }
+      t << convertToXML(inc->includeName);
+      if (inc->local)
+      {
+        t << "&quot;";
+      }
+      else
+      {
+        t << "&gt;";
+      }
       t << "</programlisting>" << endl;
     }
   }
