@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
  * Copyright (C) 1997-2012 by Dimitri van Heesch.
@@ -32,6 +32,7 @@
 #include "config.h"
 #include "filedef.h"
 #include "msc.h"
+#include "dia.h"
 
 DocbookDocVisitor::DocbookDocVisitor(FTextStream &t,CodeOutputInterface &ci)
   : DocVisitor(DocVisitor_Docbook), m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE)
@@ -249,12 +250,13 @@ void DocbookDocVisitor::visit(DocStyleChange *s)
 void DocbookDocVisitor::visit(DocVerbatim *s)
 {
   if (m_hide) return;
+  SrcLangExt langExt = getLanguageFromFileName(m_langExt);
   switch(s->type())
   {
     case DocVerbatim::Code: // fall though
       m_t << "<programlisting>";
       Doxygen::parserManager->getParser(m_langExt)
-        ->parseCode(m_ci,s->context(),s->text(),
+        ->parseCode(m_ci,s->context(),s->text(),langExt,
             s->isExample(),s->exampleFile());
       m_t << "</programlisting>";
       break;
@@ -346,6 +348,7 @@ void DocbookDocVisitor::visit(DocAnchor *anc)
 void DocbookDocVisitor::visit(DocInclude *inc)
 {
   if (m_hide) return;
+  SrcLangExt langExt = getLanguageFromFileName(inc->extension());
   switch(inc->type())
   {
     case DocInclude::IncWithLines:
@@ -356,6 +359,7 @@ void DocbookDocVisitor::visit(DocInclude *inc)
         Doxygen::parserManager->getParser(inc->extension())
           ->parseCode(m_ci,inc->context(),
               inc->text(),
+              langExt,
               inc->isExample(),
               inc->exampleFile(), &fd);
         m_t << "</programlisting>";
@@ -366,6 +370,7 @@ void DocbookDocVisitor::visit(DocInclude *inc)
       Doxygen::parserManager->getParser(inc->extension())
         ->parseCode(m_ci,inc->context(),
             inc->text(),
+            langExt,
             inc->isExample(),
             inc->exampleFile());
       m_t << "</programlisting>";
@@ -385,6 +390,7 @@ void DocbookDocVisitor::visit(DocInclude *inc)
         ->parseCode(m_ci,
             inc->context(),
             extractBlock(inc->text(),inc->blockId()),
+            langExt,
             inc->isExample(),
             inc->exampleFile()
             );
@@ -404,6 +410,7 @@ void DocbookDocVisitor::visit(DocIncOperator *op)
     pushEnabled();
     m_hide = TRUE;
   }
+  SrcLangExt langExt = getLanguageFromFileName(m_langExt);
   if (op->type()!=DocIncOperator::Skip)
   {
     popEnabled();
@@ -411,7 +418,7 @@ void DocbookDocVisitor::visit(DocIncOperator *op)
     {
       Doxygen::parserManager->getParser(m_langExt)
         ->parseCode(m_ci,op->context(),
-            op->text(),op->isExample(),
+            op->text(),langExt,op->isExample(),
             op->exampleFile());
     }
     pushEnabled();
@@ -1001,6 +1008,18 @@ void DocbookDocVisitor::visitPost(DocMscFile *df)
   if (m_hide) return;
   endMscFile(df->hasCaption());
 }
+void DocbookDocVisitor::visitPre(DocDiaFile *df)
+{
+  if (m_hide) return;
+  startDiaFile(df->file(),df->width(),df->height(),df->hasCaption());
+}
+
+void DocbookDocVisitor::visitPost(DocDiaFile *df)
+{
+  if (m_hide) return;
+  endDiaFile(df->hasCaption());
+}
+
 void DocbookDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
@@ -1141,6 +1160,7 @@ void DocbookDocVisitor::visitPost(DocParamList *)
 void DocbookDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
   m_t << "<para><link linkend=\"";
   m_t << x->file() << "_1" << x->anchor();
   m_t << "\">";
@@ -1149,9 +1169,10 @@ void DocbookDocVisitor::visitPre(DocXRefItem *x)
   m_t << " ";
 }
 
-void DocbookDocVisitor::visitPost(DocXRefItem *)
+void DocbookDocVisitor::visitPost(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
   m_t << "</para>";
 }
 
@@ -1217,6 +1238,15 @@ void DocbookDocVisitor::visitPost(DocVhdlFlow *)
   // TODO: to be implemented
 }
 
+void DocbookDocVisitor::visitPre(DocParBlock *)
+{
+}
+
+void DocbookDocVisitor::visitPost(DocParBlock *)
+{
+}
+
+
 void DocbookDocVisitor::filter(const char *str)
 {
   m_t << convertToXML(str);
@@ -1321,6 +1351,80 @@ void DocbookDocVisitor::endMscFile(bool hasCaption)
   m_t << "</para>" << endl;
 }
 
+void DocbookDocVisitor::writeDiaFile(const QCString &baseName)
+{
+  QCString shortName = baseName;
+  int i;
+  if ((i=shortName.findRev('/'))!=-1)
+  {
+    shortName=shortName.right(shortName.length()-i-1);
+  }
+  QCString outDir = Config_getString("DOCBOOK_OUTPUT");
+  writeDiaGraphFromFile(baseName+".dia",outDir,shortName,DIA_BITMAP);
+  m_t << "                <imagedata";
+  m_t << " align=\"center\" fileref=\"" << shortName << ".png" << "\">";
+  m_t << "</imagedata>" << endl;
+}
+
+void DocbookDocVisitor::startDiaFile(const QCString &fileName,
+    const QCString &width,
+    const QCString &height,
+    bool hasCaption
+    )
+{
+  QCString baseName=fileName;
+  int i;
+  if ((i=baseName.findRev('/'))!=-1)
+  {
+    baseName=baseName.right(baseName.length()-i-1);
+  }
+  if ((i=baseName.find('.'))!=-1)
+  {
+    baseName=baseName.left(i);
+  }
+  baseName.prepend("msc_");
+  QCString outDir = Config_getString("DOCBOOK_OUTPUT");
+  writeDiaGraphFromFile(fileName,outDir,baseName,DIA_BITMAP);
+  m_t << "<para>" << endl;
+  m_t << "    <figure>" << endl;
+  m_t << "        <title></title>" << endl;
+  m_t << "        <mediaobject>" << endl;
+  m_t << "            <imageobject>" << endl;
+  m_t << "                <imagedata";
+  if (!width.isEmpty())
+  {
+    m_t << " width=\"";
+    m_t << width;
+    m_t << "\"";
+  }
+  else if (!height.isEmpty())
+  {
+    m_t << " depth=\"";
+    m_t << height;
+    m_t << "\"";
+  }
+  m_t << " align=\"center\" fileref=\"" << baseName << ".png" << "\">";
+  m_t << "</imagedata>" << endl;
+  m_t << "            </imageobject>" << endl;
+  if (hasCaption)
+  {
+    m_t << "        <caption>" << endl;
+  }
+}
+
+void DocbookDocVisitor::endDiaFile(bool hasCaption)
+{
+  if (m_hide) return;
+  m_t << "endl";
+  if (hasCaption)
+  {
+    m_t << "        </caption>" << endl;
+  }
+  m_t << "        </mediaobject>" << endl;
+  m_t << "    </figure>" << endl;
+  m_t << "</para>" << endl;
+}
+
 void DocbookDocVisitor::writeDotFile(const QCString &baseName)
 {
   QCString shortName = baseName;
