@@ -62,7 +62,9 @@ enum Tokens
   RetVal_SwitchLang     = 0x10012,
   RetVal_CloseXml       = 0x10013,
   RetVal_EndBlockQuote  = 0x10014,
-  RetVal_CopyDoc        = 0x10015
+  RetVal_CopyDoc        = 0x10015,
+  RetVal_EndInternal    = 0x10016,
+  RetVal_EndParBlock    = 0x10017
 };
 
 /** @brief Data associated with a token used by the comment block parser. */
@@ -156,5 +158,7 @@ void doctokenizerYYsetStateAnchor();
 void doctokenizerYYsetInsidePre(bool b);
 void doctokenizerYYpushBackHtmlTag(const char *tag);
 void doctokenizerYYsetStateSnippet();
+void doctokenizerYYstartAutoList();
+void doctokenizerYYendAutoList();
 
 #endif
