@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -67,6 +67,7 @@ class DocHtmlHeader;
 class DocImage;
 class DocDotFile;
 class DocMscFile;
+class DocDiaFile;
 class DocLink;
 class DocCite;
 class DocRef;
@@ -82,6 +83,7 @@ class DocText;
 class DocSimpleSectSep;
 class DocHtmlBlockQuote;
 class DocVhdlFlow;
+class DocParBlock;
 
 /*! @brief Abstract visitor that participates in the visitor pattern.
  */
@@ -165,6 +167,8 @@ class DocVisitor
     virtual void visitPost(DocDotFile *) = 0;
     virtual void visitPre(DocMscFile *) = 0;
     virtual void visitPost(DocMscFile *) = 0;   
+    virtual void visitPre(DocDiaFile *) = 0;
+    virtual void visitPost(DocDiaFile *) = 0;
     virtual void visitPre(DocLink *) = 0;
     virtual void visitPost(DocLink *) = 0;
     virtual void visitPre(DocRef *) = 0;
@@ -189,6 +193,8 @@ class DocVisitor
     virtual void visitPost(DocHtmlBlockQuote *) = 0;
     virtual void visitPre(DocVhdlFlow *) = 0;
     virtual void visitPost(DocVhdlFlow *) = 0;
+    virtual void visitPre(DocParBlock *) = 0;
+    virtual void visitPost(DocParBlock *) = 0;
     /*! @} */
 };
 
