@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -17,8 +17,9 @@
 #include "config.h"
 #include "message.h"
 #include "doxygen.h"
+#include <qfile.h>
 
-EclipseHelp::EclipseHelp() : m_depth(0), m_endtag(FALSE), m_tocfile(0) 
+EclipseHelp::EclipseHelp() : m_depth(0), m_endtag(FALSE), m_openTags(0), m_tocfile(0) 
 {
 }
 
@@ -50,6 +51,7 @@ void EclipseHelp::openedTag()
   {
     m_tocstream << ">" << endl;
     m_endtag = FALSE;
+    ++m_openTags;
   }
 }
 
@@ -143,8 +145,13 @@ void EclipseHelp::decContentsDepth()
   // -- end of the opened topic
   closedTag();
   --m_depth;
-  indent();
-  m_tocstream << "</topic>" << endl;
+
+  if (m_openTags==m_depth)
+  {
+    --m_openTags;
+    indent();
+    m_tocstream << "</topic>" << endl;
+  }
 }
 
 /*!
@@ -157,6 +164,7 @@ void EclipseHelp::decContentsDepth()
  * @param anchor Name of an anchor of the item.
  * @param separateIndex not used.
  * @param addToNavIndex not used.
+ * @param def not used.
  */
 void EclipseHelp::addContentsItem(
     bool /* isDir */,
@@ -165,28 +173,52 @@ void EclipseHelp::addContentsItem(
     const char *file,
     const char *anchor,
     bool /* separateIndex */,
-    bool /* addToNavIndex */) 
+    bool /* addToNavIndex */,
+    Definition * /*def*/) 
 {
   // -- write the topic tag 
   closedTag();
-  indent();
-  m_tocstream << "<topic label=\"" << convertToXML(name) << "\"";
   if (file) 
   { 
-    m_tocstream << " href=\"" << convertToXML(m_pathprefix) 
-                << file << Doxygen::htmlFileExtension;
-    if (anchor)
+    switch (file[0]) // check for special markers (user defined URLs)
     {
-      m_tocstream << "#" << anchor;
+      case '^':
+        // URL not supported by eclipse toc.xml
+	break;
+
+      case '!':
+        indent();
+        m_tocstream << "<topic label=\"" << convertToXML(name) << "\"";
+        m_tocstream << " href=\"" << convertToXML(m_pathprefix) << &file[1] << "\"";
+        m_endtag = TRUE;
+	break;
+
+      default:
+        indent();
+        m_tocstream << "<topic label=\"" << convertToXML(name) << "\"";
+        m_tocstream << " href=\"" << convertToXML(m_pathprefix) 
+                    << file << Doxygen::htmlFileExtension;
+        if (anchor)
+        {
+          m_tocstream << "#" << anchor;
+        }
+        m_tocstream << "\"";
+        m_endtag = TRUE;
+	break;
     }
-    m_tocstream << "\"";
   }
-  m_endtag = TRUE;
+  else
+  {
+    indent();
+    m_tocstream << "<topic label=\"" << convertToXML(name) << "\"";
+    m_endtag = TRUE;
+  }
 }
 
 void EclipseHelp::addIndexItem(
     Definition * /* context */,
     MemberDef * /* md */,
+    const char * /* sectionAnchor */,
     const char * /* title */)
 {
 }
