@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -54,12 +54,13 @@ class DevNullCodeDocInterface : public CodeOutputInterface
     virtual void writeCodeLink(const char *,const char *,
                                const char *,const char *,
                                const char *) {}
+    virtual void writeTooltip(const char *, const DocLinkInfo &, const char *,
+                              const char *, const SourceLinkInfo &, const SourceLinkInfo &
+                             ) {}
     virtual void writeLineNumber(const char *,const char *,
                                  const char *,int) {}
     virtual void startCodeLine(bool) {}
     virtual void endCodeLine() {}
-    virtual void startCodeAnchor(const char *) {}
-    virtual void endCodeAnchor() {}
     virtual void startFontClass(const char *) {}
     virtual void endFontClass() {}
     virtual void writeCodeAnchor(const char *) {}
@@ -513,7 +514,7 @@ void FileDef::writeSummaryLinks(OutputList &ol)
       MemberList * ml = getMemberList(lmd->type);
       if (ml && ml->declVisible())
       {
-        ol.writeSummaryLink(0,ml->listTypeAsString(),lmd->title(lang),first);
+        ol.writeSummaryLink(0,MemberList::listTypeAsString(ml->listType()),lmd->title(lang),first);
         first=FALSE;
       }
     }
@@ -806,6 +807,7 @@ void FileDef::writeSource(OutputList &ol,bool sameTu,QStrList &filesInSameTu)
   static bool generateTreeView  = Config_getBool("GENERATE_TREEVIEW");
   static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
   static bool latexSourceCode   = Config_getBool("LATEX_SOURCE_CODE");
+  DevNullCodeDocInterface devNullIntf;
   QCString title = m_docname;
   if (!m_fileVersion.isEmpty())
   {
@@ -877,9 +879,33 @@ void FileDef::writeSource(OutputList &ol,bool sameTu,QStrList &filesInSameTu)
     ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
     pIntf->resetCodeParserState();
     ol.startCodeFragment();
+    bool needs2PassParsing = 
+        Doxygen::parseSourcesNeeded &&                // we need to parse (filtered) sources for cross-references
+        !filterSourceFiles &&                         // but user wants to show sources as-is
+        !getFileFilter(absFilePath(),TRUE).isEmpty(); // and there is a filter used while parsing
+
+    if (needs2PassParsing)
+    {
+      // parse code for cross-references only (see bug707641)
+      pIntf->parseCode(devNullIntf,0,
+                       fileToString(absFilePath(),TRUE,TRUE),
+                       getLanguage(),
+                       FALSE,0,this
+                      );
+    }
     pIntf->parseCode(ol,0,
         fileToString(absFilePath(),filterSourceFiles,TRUE),
-        FALSE,0,this
+        getLanguage(),      // lang
+        FALSE,              // isExampleBlock
+        0,                  // exampleName
+        this,               // fileDef
+        -1,                 // startLine
+        -1,                 // endLine
+        FALSE,              // inlineFragment
+        0,                  // memberDef
+        TRUE,               // showLineNumbers
+        0,                  // searchCtx
+        !needs2PassParsing  // collectXRefs
         );
     ol.endCodeFragment();
   }
@@ -917,6 +943,7 @@ void FileDef::parseSource(bool sameTu,QStrList &filesInSameTu)
     pIntf->parseCode(
             devNullIntf,0,
             fileToString(absFilePath(),filterSourceFiles,TRUE),
+            getLanguage(),
             FALSE,0,this
            );
   }
@@ -1643,14 +1670,7 @@ QCString FileDef::getSourceFileBase() const
 /*! Returns the name of the verbatim copy of this file (if any). */
 QCString FileDef::includeName() const 
 { 
-  if (Htags::useHtags)
-  {
-    return Htags::path2URL(m_filePath);
-  }
-  else
-  {
-    return convertNameToFile(m_diskName)+"_source"; 
-  }
+  return getSourceFileBase();
 }
 
 MemberList *FileDef::createMemberList(MemberListType lt)
@@ -1774,3 +1794,9 @@ void FileDef::getAllIncludeFilesRecursively(QStrList &incFiles) const
   QDict<void> includes(257);
   ::getAllIncludeFilesRecursively(&includes,this,incFiles);
 }
+
+QCString FileDef::title() const
+{
+  return theTranslator->trFileReference(name());
+}
+
