@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: filedef.h,v 1.32 2001/03/19 19:27:40 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -131,6 +131,8 @@ class FileDef : public Definition
     MemberGroupSDict *getMemberGroupSDict() const { return m_memberGroupSDict; }
     NamespaceSDict *getNamespaceSDict() const     { return m_namespaceSDict; }
     ClassSDict *getClassSDict() const             { return m_classSDict; }
+
+    QCString title() const;
     
     //---------------------------------
 
@@ -294,7 +296,6 @@ class DirEntry
   private:
     EntryKind m_kind;
     FileDef   *m_fd;
-    int num;
     bool m_isLast;
 };
 
