@@ -21,11 +21,14 @@
 class CodeOutputInterface;
 class FileDef;
 class MemberDef;
+class QCString;
+class Definition;
 
 void parseFortranCode(CodeOutputInterface &,const char *,const QCString &, 
             bool ,const char *,FileDef *fd,
             int startLine,int endLine,bool inlineFragment,
-            MemberDef *memberDef,bool showLineNumbers,Definition *searchCtx);
+            MemberDef *memberDef,bool showLineNumbers,Definition *searchCtx,
+            bool collectRefs);
 void resetFortranCodeParserState();
 void codeFreeScanner();
 
