@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -28,6 +28,7 @@
 #include "htmlgen.h"
 #include "parserintf.h"
 #include "msc.h"
+#include "dia.h"
 #include "util.h"
 #include "vhdldocgen.h"
 #include "filedef.h"
@@ -102,6 +103,8 @@ static bool mustBeOutsideParagraph(DocNode *n)
         case DocNode::Kind_Copy:
           /* <blockquote> */
         case DocNode::Kind_HtmlBlockQuote:
+          /* \parblock */
+        case DocNode::Kind_ParBlock:
           return TRUE;
         case DocNode::Kind_StyleChange:
           return ((DocStyleChange*)n)->style()==DocStyleChange::Preformatted ||
@@ -136,9 +139,9 @@ static QString htmlAttribsToString(const HtmlAttribList &attribs)
 //-------------------------------------------------------------------------
 
 HtmlDocVisitor::HtmlDocVisitor(FTextStream &t,CodeOutputInterface &ci,
-                               Definition *ctx,MemberDef *md) 
+                               Definition *ctx) 
   : DocVisitor(DocVisitor_Html), m_t(t), m_ci(ci), m_insidePre(FALSE), 
-                                 m_hide(FALSE), m_ctx(ctx), m_md(md)
+                                 m_hide(FALSE), m_ctx(ctx)
 {
   if (ctx) m_langExt=ctx->getDefFileExtension();
 }
@@ -417,6 +420,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
   {
     lang = s->language();
   }
+  SrcLangExt langExt = getLanguageFromFileName(lang);
   switch(s->type())
   {
     case DocVerbatim::Code: 
@@ -426,6 +430,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
                             ->parseCode(m_ci,
                                         s->context(),
                                         s->text(),
+                                        langExt,
                                         s->isExample(),
                                         s->exampleFile(),
                                         0,     // fileDef
@@ -526,6 +531,7 @@ void HtmlDocVisitor::visit(DocAnchor *anc)
 void HtmlDocVisitor::visit(DocInclude *inc)
 {
   if (m_hide) return;
+  SrcLangExt langExt = getLanguageFromFileName(inc->extension());
   switch(inc->type())
   {
     case DocInclude::Include: 
@@ -535,6 +541,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
                             ->parseCode(m_ci,                 
                                         inc->context(),
                                         inc->text(),
+                                        langExt,
                                         inc->isExample(),
                                         inc->exampleFile(),
                                         0,     // fileDef
@@ -558,6 +565,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
                                ->parseCode(m_ci,
                                            inc->context(),
                                            inc->text(),
+                                           langExt,
                                            inc->isExample(),
                                            inc->exampleFile(), 
                                            &fd,   // fileDef,
@@ -592,6 +600,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
                                ->parseCode(m_ci,
                                            inc->context(),
                                            extractBlock(inc->text(),inc->blockId()),
+                                           langExt,
                                            inc->isExample(),
                                            inc->exampleFile(), 
                                            0,
@@ -619,6 +628,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
     pushEnabled();
     m_hide=TRUE;
   }
+  SrcLangExt langExt = getLanguageFromFileName(m_langExt);
   if (op->type()!=DocIncOperator::Skip) 
   {
     popEnabled();
@@ -629,6 +639,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
                                 m_ci,
                                 op->context(),
                                 op->text(),
+                                langExt,
                                 op->isExample(),
                                 op->exampleFile(),
                                 0,     // fileDef
@@ -821,21 +832,21 @@ bool isSeparatedParagraph(DocSimpleSect *parent,DocPara *par)
   int i = nodes.findRef(par);
   if (i==-1) return FALSE;
   int count = parent->children().count();
-  if (count>1 && i==0)
+  if (count>1 && i==0) // first node
   {
     if (nodes.at(i+1)->kind()==DocNode::Kind_SimpleSectSep)
     {
       return TRUE;
     }
   }
-  else if (count>1 && i==count-1)
+  else if (count>1 && i==count-1) // last node
   {
     if (nodes.at(i-1)->kind()==DocNode::Kind_SimpleSectSep)
     {
       return TRUE;
     }
   }
-  else if (count>2 && i>0 && i<count-1)
+  else if (count>2 && i>0 && i<count-1) // intermediate node
   {
     if (nodes.at(i-1)->kind()==DocNode::Kind_SimpleSectSep &&
         nodes.at(i+1)->kind()==DocNode::Kind_SimpleSectSep)
@@ -855,9 +866,58 @@ static int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
   {
     switch (p->parent()->kind()) 
     {
+      case DocNode::Kind_ParBlock:
+        { // hierarchy: node N -> para -> parblock -> para
+          // adapt return value to kind of N
+          DocNode::Kind kind = DocNode::Kind_Para;
+          if ( p->parent()->parent() && p->parent()->parent()->parent() )
+          {
+            kind = p->parent()->parent()->parent()->kind();
+          }
+          isFirst=isFirstChildNode((DocParBlock*)p->parent(),p);
+          isLast =isLastChildNode ((DocParBlock*)p->parent(),p);
+          t=0;
+          if (isFirst)
+          {
+            if (kind==DocNode::Kind_HtmlListItem ||
+                kind==DocNode::Kind_SecRefItem)
+            {
+              t=1;
+            }
+            else if (kind==DocNode::Kind_HtmlDescData ||
+                     kind==DocNode::Kind_XRefItem ||
+                     kind==DocNode::Kind_SimpleSect)
+            {
+              t=2;
+            }
+            else if (kind==DocNode::Kind_HtmlCell ||
+                     kind==DocNode::Kind_ParamList)
+            {
+              t=5;
+            }
+          }
+          if (isLast)
+          {
+            if (kind==DocNode::Kind_HtmlListItem ||
+                kind==DocNode::Kind_SecRefItem)
+            {
+              t=3;
+            }
+            else if (kind==DocNode::Kind_HtmlDescData ||
+                     kind==DocNode::Kind_XRefItem ||
+                     kind==DocNode::Kind_SimpleSect)
+            {
+              t=4;
+            }
+            else if (kind==DocNode::Kind_HtmlCell ||
+                     kind==DocNode::Kind_ParamList)
+            {
+              t=6;
+            }
+          }
+          break;
+        }
       case DocNode::Kind_AutoListItem:
-        //isFirst=TRUE;
-        //isLast =TRUE;
         isFirst=isFirstChildNode((DocAutoListItem*)p->parent(),p);
         isLast =isLastChildNode ((DocAutoListItem*)p->parent(),p);
         t=1; // not used
@@ -896,12 +956,6 @@ static int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
         if (isFirst) t=2;
         if (isLast)  t=4;
         break;
-      case DocNode::Kind_HtmlCell:
-        isFirst=isFirstChildNode((DocHtmlCell*)p->parent(),p);
-        isLast =isLastChildNode ((DocHtmlCell*)p->parent(),p);
-        if (isFirst) t=5;
-        if (isLast)  t=6;
-        break;
       case DocNode::Kind_SimpleSect:
         isFirst=isFirstChildNode((DocSimpleSect*)p->parent(),p);
         isLast =isLastChildNode ((DocSimpleSect*)p->parent(),p);
@@ -915,6 +969,12 @@ static int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
           isFirst=isLast=TRUE;
         }
         break;
+      case DocNode::Kind_HtmlCell:
+        isFirst=isFirstChildNode((DocHtmlCell*)p->parent(),p);
+        isLast =isLastChildNode ((DocHtmlCell*)p->parent(),p);
+        if (isFirst) t=5;
+        if (isLast)  t=6;
+        break;
       default:
         break;
     }
@@ -947,6 +1007,7 @@ void HtmlDocVisitor::visitPre(DocPara *p)
       case DocNode::Kind_XRefItem:
       case DocNode::Kind_Copy:
       case DocNode::Kind_HtmlBlockQuote:
+      case DocNode::Kind_ParBlock:
         needsTag = TRUE;
         break;
       case DocNode::Kind_Root:
@@ -1020,6 +1081,7 @@ void HtmlDocVisitor::visitPost(DocPara *p)
       case DocNode::Kind_XRefItem:
       case DocNode::Kind_Copy:
       case DocNode::Kind_HtmlBlockQuote:
+      case DocNode::Kind_ParBlock:
         needsTag = TRUE;
         break;
       case DocNode::Kind_Root:
@@ -1485,6 +1547,26 @@ void HtmlDocVisitor::visitPost(DocMscFile *df)
   m_t << "</div>" << endl;
 }
 
+void HtmlDocVisitor::visitPre(DocDiaFile *df)
+{
+  if (m_hide) return;
+  m_t << "<div class=\"diagraph\">" << endl;
+  writeDiaFile(df->file(),df->relPath(),df->context());
+  if (df->hasCaption())
+  {
+    m_t << "<div class=\"caption\">" << endl;
+  }
+}
+void HtmlDocVisitor::visitPost(DocDiaFile *df)
+{
+  if (m_hide) return;
+  if (df->hasCaption())
+  {
+    m_t << "</div>" << endl;
+  }
+  m_t << "</div>" << endl;
+}
+
 void HtmlDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
@@ -1695,6 +1777,8 @@ void HtmlDocVisitor::visitPost(DocParamList *)
 void HtmlDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
+
   forceEndParagraph(x);
   bool anonymousEnum = x->file()=="@";
   if (!anonymousEnum)
@@ -1716,6 +1800,7 @@ void HtmlDocVisitor::visitPre(DocXRefItem *x)
 void HtmlDocVisitor::visitPost(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
   m_t << "</dd></dl>" << endl;
   forceStartParagraph(x);
 }
@@ -1803,6 +1888,18 @@ void HtmlDocVisitor::visitPost(DocVhdlFlow *vf)
   }
 }
 
+void HtmlDocVisitor::visitPre(DocParBlock *)
+{
+  if (m_hide) return;
+}
+
+void HtmlDocVisitor::visitPost(DocParBlock *)
+{
+  if (m_hide) return;
+}
+
+
+
 void HtmlDocVisitor::filter(const char *str)
 { 
   if (str==0) return;
@@ -1934,8 +2031,33 @@ void HtmlDocVisitor::writeMscFile(const QCString &fileName,
   }
   baseName.prepend("msc_");
   QCString outDir = Config_getString("HTML_OUTPUT");
-  writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
-  writeMscImageMapFromFile(m_t,fileName,outDir,relPath,baseName,context);
+  QCString imgExt = Config_getEnum("DOT_IMAGE_FORMAT");
+  MscOutputFormat mscFormat = MSC_BITMAP;
+  if ("svg" == imgExt)
+    mscFormat = MSC_SVG;
+  writeMscGraphFromFile(fileName,outDir,baseName,mscFormat);
+  writeMscImageMapFromFile(m_t,fileName,outDir,relPath,baseName,context,mscFormat);
+}
+
+void HtmlDocVisitor::writeDiaFile(const QCString &fileName,
+                                  const QCString &,
+                                  const QCString &)
+{
+  QCString baseName=fileName;
+  int i;
+  if ((i=baseName.findRev('/'))!=-1) // strip path
+  {
+    baseName=baseName.right(baseName.length()-i-1);
+  }
+  if ((i=baseName.find('.'))!=-1) // strip extension
+  {
+    baseName=baseName.left(i);
+  }
+  baseName.prepend("dia_");
+  QCString outDir = Config_getString("HTML_OUTPUT");
+  writeDiaGraphFromFile(fileName,outDir,baseName,DIA_BITMAP);
+
+  m_t << "<img src=\"" << outDir << '/' << baseName << ".png" << "\" />" << endl;
 }
 
 /** Used for items found inside a paragraph, which due to XHTML restrictions
