@@ -1,12 +1,12 @@
 /******************************************************************************
  *
- * 
+ *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -21,7 +21,6 @@
 #include "language.h"
 #include "lang_cfg.h"
 #include "translator.h"
-#include "translatordecoder.h"
 #include "translator_en.h"
 #if !defined(ENGLISH_ONLY)
 #include "translator_adapter.h"
@@ -127,6 +126,9 @@
 #ifdef LANG_LT
 #include "translator_lt.h"
 #endif
+#ifdef LANG_LV
+#include "translator_lv.h"
+#endif
 #ifdef LANG_ZA
 #include "translator_za.h"
 #endif
@@ -186,7 +188,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_SV
   else if (L_EQUAL("swedish"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorSwedish);
+    theTranslator=new TranslatorSwedish;
   }
 #endif
 #ifdef LANG_CZ
@@ -195,19 +197,19 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorCzech;
   }
 #endif
-#ifdef LANG_FR  
+#ifdef LANG_FR
   else if (L_EQUAL("french"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorFrench);
+    theTranslator=new TranslatorFrench;
   }
 #endif
-#ifdef LANG_ID  
+#ifdef LANG_ID
   else if (L_EQUAL("indonesian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorIndonesian);
+    theTranslator=new TranslatorIndonesian;
   }
 #endif
-#ifdef LANG_IT  
+#ifdef LANG_IT
   else if (L_EQUAL("italian"))
   {
     theTranslator=new TranslatorItalian;
@@ -222,13 +224,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_JP
   else if (L_EQUAL("japanese"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorJapanese);
+    theTranslator=new TranslatorJapanese;
   }
 #endif
 #ifdef LANG_JE
   else if (L_EQUAL("japanese-en"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorJapaneseEn);
+    theTranslator=new TranslatorJapaneseEn;
   }
 #endif
 #ifdef LANG_ES
@@ -246,7 +248,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_RU
   else if (L_EQUAL("russian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorRussian);
+    theTranslator=new TranslatorRussian;
   }
 #endif
 #ifdef LANG_HR
@@ -270,31 +272,31 @@ bool setTranslator(const char *langName)
 #ifdef LANG_HU
   else if (L_EQUAL("hungarian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorHungarian);
+    theTranslator=new TranslatorHungarian;
   }
 #endif
 #ifdef LANG_KR
   else if (L_EQUAL("korean"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorKorean);
+    theTranslator=new TranslatorKorean;
   }
 #endif
 #ifdef LANG_KE
   else if (L_EQUAL("korean-en"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorKoreanEn);
+    theTranslator=new TranslatorKoreanEn;
   }
 #endif
 #ifdef LANG_RO
   else if (L_EQUAL("romanian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorRomanian);
+    theTranslator=new TranslatorRomanian;
   }
 #endif
 #ifdef LANG_SI
   else if (L_EQUAL("slovene"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorSlovene);
+    theTranslator=new TranslatorSlovene;
   }
 #endif
 #ifdef LANG_CN
@@ -306,13 +308,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_TW
   else if (L_EQUAL("chinese-traditional"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorChinesetraditional);
+    theTranslator=new TranslatorChinesetraditional;
   }
 #endif
 #ifdef LANG_NO
   else if (L_EQUAL("norwegian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorNorwegian);
+    theTranslator=new TranslatorNorwegian;
   }
 #endif
 #ifdef LANG_BR
@@ -324,7 +326,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_DK
   else if (L_EQUAL("danish"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorDanish);
+    theTranslator=new TranslatorDanish;
   }
 #endif
 #ifdef LANG_SK
@@ -336,7 +338,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_UA
   else if (L_EQUAL("ukrainian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorUkrainian);
+    theTranslator=new TranslatorUkrainian;
   }
 #endif
 #ifdef LANG_GR
@@ -348,13 +350,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_SR
   else if (L_EQUAL("serbian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorSerbian);
+    theTranslator=new TranslatorSerbian;
   }
 #endif
 #ifdef LANG_SC
-  else if (L_EQUAL("serbian-cyrilic"))
+  else if (L_EQUAL("serbian-cyrillic") || L_EQUAL("serbiancyr")) /* serbiancyr for consistency with older versions */
   {
-    theTranslator=new TranslatorSerbian;
+    theTranslator=new TranslatorSerbianCyrillic;
   }
 #endif
 #ifdef LANG_CA
@@ -366,19 +368,25 @@ bool setTranslator(const char *langName)
 #ifdef LANG_LT
   else if (L_EQUAL("lithuanian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorLithuanian);
+    theTranslator=new TranslatorLithuanian;
+  }
+#endif
+#ifdef LANG_LV
+  else if (L_EQUAL("latvian"))
+  {
+    theTranslator=new TranslatorLatvian;
   }
 #endif
 #ifdef LANG_ZA
   else if (L_EQUAL("afrikaans"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorAfrikaans);
+    theTranslator=new TranslatorAfrikaans;
   }
 #endif
 #ifdef LANG_AR
   else if (L_EQUAL("arabic"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorArabic);
+    theTranslator=new TranslatorArabic;
   }
 #endif
 #ifdef LANG_FA
@@ -417,8 +425,8 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorEnglish;
     return FALSE;
   }
-  
+
   QCString msg = theTranslator->updateNeededMessage();
-  if (!msg.isEmpty()) err(msg);
+  if (!msg.isEmpty()) warn_uncond(msg);
   return TRUE;
 }
