@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -110,6 +110,8 @@ class LatexDocVisitor : public DocVisitor
     void visitPost(DocDotFile *);
     void visitPre(DocMscFile *);
     void visitPost(DocMscFile *);
+    void visitPre(DocDiaFile *);
+    void visitPost(DocDiaFile *);
     void visitPre(DocLink *lnk);
     void visitPost(DocLink *);
     void visitPre(DocRef *ref);
@@ -134,6 +136,8 @@ class LatexDocVisitor : public DocVisitor
     void visitPost(DocHtmlBlockQuote *);
     void visitPre(DocVhdlFlow *);
     void visitPost(DocVhdlFlow *);
+    void visitPre(DocParBlock *);
+    void visitPost(DocParBlock *);
 
   private:
 
@@ -168,6 +172,11 @@ class LatexDocVisitor : public DocVisitor
     void endMscFile(bool hasCaption);
     void writeMscFile(const QCString &fileName);
 
+    void startDiaFile(const QCString &fileName,const QCString &width,
+                      const QCString &height, bool hasCaption);
+    void endDiaFile(bool hasCaption);
+    void writeDiaFile(const QCString &fileName);
+
     void pushEnabled();
     void popEnabled();
 
