@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -38,7 +38,7 @@
 #include "filename.h"
 
 static const char doxygenLatexStyle[] =
-#include "doxygen_sty.h"
+#include "doxygen.sty.h"
 ;
 
 //static QCString filterTitle(const char *s)
@@ -126,7 +126,7 @@ static void writeLatexMakefile()
     }
     t << "\techo \"Rerunning latex....\"" << endl
       << "\t" << latex_command << " refman.tex" << endl
-      << "\tlatex_count=5 ; \\" << endl
+      << "\tlatex_count=8 ; \\" << endl
       << "\twhile egrep -s 'Rerun (LaTeX|to get cross-references right)' refman.log && [ $$latex_count -gt 0 ] ;\\" << endl
       << "\t    do \\" << endl
       << "\t      echo \"Rerunning latex....\" ;\\" << endl
@@ -154,7 +154,7 @@ static void writeLatexMakefile()
       t << "\tpdflatex refman" << endl;
     }
     t << "\tpdflatex refman" << endl
-      << "\tlatex_count=5 ; \\" << endl
+      << "\tlatex_count=8 ; \\" << endl
       << "\twhile egrep -s 'Rerun (LaTeX|to get cross-references right)' refman.log && [ $$latex_count -gt 0 ] ;\\" << endl
       << "\t    do \\" << endl
       << "\t      echo \"Rerunning latex....\" ;\\" << endl
@@ -199,7 +199,7 @@ static void writeMakeBat()
       t << latex_command << " refman.tex\n";
     }
     t << "setlocal enabledelayedexpansion\n";
-    t << "set count=5\n";
+    t << "set count=8\n";
     t << ":repeat\n";
     t << "set content=X\n";
     t << "for /F \"tokens=*\" %%T in ( 'findstr /C:\"Rerun LaTeX\" refman.log' ) do set content=\"%%~T\"\n";
@@ -231,7 +231,7 @@ static void writeMakeBat()
     t << "echo ----\n";
     t << "pdflatex refman\n\n";
     t << "setlocal enabledelayedexpansion\n";
-    t << "set count=5\n";
+    t << "set count=8\n";
     t << ":repeat\n";
     t << "set content=X\n";
     t << "for /F \"tokens=*\" %%T in ( 'findstr /C:\"Rerun LaTeX\" refman.log' ) do set content=\"%%~T\"\n";
@@ -366,8 +366,12 @@ static void writeDefaultHeaderPart1(FTextStream &t)
        "\n";
 
   // Headers & footers
-  QCString genString =
-        theTranslator->trGeneratedAt(dateToString(TRUE),Config_getString("PROJECT_NAME"));
+  QGString genString;
+  FTextStream tg(&genString);
+  filterLatexString(tg,
+                    theTranslator->trGeneratedAt(dateToString(TRUE),
+                       Config_getString("PROJECT_NAME")),
+                    FALSE,FALSE,FALSE);
   t << "% Headers & footers\n"
        "\\usepackage{fancyhdr}\n"
        "\\pagestyle{fancyplain}\n"
@@ -521,10 +525,15 @@ static void writeDefaultFooter(FTextStream &t)
   Doxygen::citeDict->writeLatexBibliography(t);
 
   // Index
+  QCString unit;
+  if (Config_getBool("COMPACT_LATEX"))
+    unit = "section";
+  else
+    unit = "chapter";
   t << "% Index\n"
        "\\newpage\n"
        "\\phantomsection\n"
-       "\\addcontentsline{toc}{part}{" << theTranslator->trRTFGeneralIndex() << "}\n"
+       "\\addcontentsline{toc}{" << unit << "}{" << theTranslator->trRTFGeneralIndex() << "}\n"
        "\\printindex\n"
        "\n"
        "\\end{document}\n";
@@ -2053,6 +2062,8 @@ void LatexGenerator::endCodeFragment()
 
 void LatexGenerator::writeLineNumber(const char *ref,const char *fileName,const char *anchor,int l)
 {
+  static bool usePDFLatex = Config_getBool("USE_PDFLATEX");
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
   if (m_prettyCode)
   {
     QCString lineNumber;
@@ -2063,9 +2074,12 @@ void LatexGenerator::writeLineNumber(const char *ref,const char *fileName,const
       QCString lineAnchor;
       lineAnchor.sprintf("_l%05d",l);
       lineAnchor.prepend(sourceFileName);
-      startCodeAnchor(lineAnchor);
+      //if (!m_prettyCode) return;
+      if (usePDFLatex && pdfHyperlinks)
+      {
+        t << "\\hypertarget{" << stripPath(lineAnchor) << "}{}";
+      }
       writeCodeLink(ref,fileName,anchor,lineNumber,0);
-      endCodeAnchor();
     }
     else
     { 
@@ -2101,21 +2115,6 @@ void LatexGenerator::endFontClass()
   t << "}";
 }
 
-void LatexGenerator::startCodeAnchor(const char *name) 
-{
-  static bool usePDFLatex = Config_getBool("USE_PDFLATEX");
-  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
-  //if (!m_prettyCode) return;
-  if (usePDFLatex && pdfHyperlinks)
-  {
-    t << "\\hypertarget{" << stripPath(name) << "}{}";
-  }
-}
-
-void LatexGenerator::endCodeAnchor() 
-{
-}
-
 void LatexGenerator::startInlineHeader()
 {
   if (Config_getBool("COMPACT_LATEX")) 
