@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: latexgen.h,v 1.50 2001/03/19 19:27:41 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -87,6 +87,9 @@ class LatexGenerator : public OutputGenerator
     void writeCodeLink(const char *ref, const char *file,
                        const char *anchor,const char *name,
                        const char *tooltip);
+    void writeTooltip(const char *, const DocLinkInfo &, const char *,
+                      const char *, const SourceLinkInfo &, const SourceLinkInfo &
+                     ) {}
     void startTextLink(const char *,const char *);
     void endTextLink();
     void startHtmlLink(const char *url);
@@ -148,8 +151,6 @@ class LatexGenerator : public OutputGenerator
     void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *);
-    void startCodeAnchor(const char *);
-    void endCodeAnchor();
     void writeChar(char c);
     void writeLatexSpacing() { t << "\\hspace{0.3cm}"; }
     void writeStartAnnoItem(const char *type,const char *file, 
