@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: layout.cpp,v 1.2 2001/03/19 19:27:41 root Exp $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -33,7 +33,7 @@
 #include <qtextstream.h>
 
 static const char layout_default[] =
-#include "layout_default.h"
+#include "layout_default.xml.h"
 ;
 
 #define ADD_OPTION(langId,text) "|"+QCString().setNum(langId)+"="+text
@@ -582,7 +582,7 @@ class LayoutParser : public QXmlDefaultHandler
                                            SrcLangExt_Fortran,theTranslator->trModules()
                                          )));
       m_sHandler.insert("file/memberdecl/constantgroups",
-          new StartElementHandlerSection(this,LayoutDocEntry::FileNamespaces,&LayoutParser::startSectionEntry,
+          new StartElementHandlerSection(this,LayoutDocEntry::FileConstantGroups,&LayoutParser::startSectionEntry,
                                          theTranslator->trConstantGroups()));
       m_sHandler.insert("file/memberdecl/defines", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDeclEntry,
