@@ -75,6 +75,7 @@ class MemberDef : public Definition
     int initializerLines() const;
     uint64 getMemberSpecifiers() const;
     MemberList *getSectionList(Definition *d) const;
+    QCString    displayDefinition() const;
 
     // scope query members
     ClassDef *getClassDef() const;
@@ -169,6 +170,7 @@ class MemberDef : public Definition
     bool hasMultiLineInitializer() const;
     bool protectionVisible() const;
     bool showInCallGraph() const;
+    bool isStrongEnumValue() const;
 
     // output info
     bool isLinkableInProject() const;
@@ -215,6 +217,7 @@ class MemberDef : public Definition
 
     bool fromAnonymousScope() const;
     bool anonymousDeclShown() const;
+    MemberDef *fromAnonymousMember() const;
 
     // callgraph related members
     bool hasCallGraph() const;
@@ -240,6 +243,16 @@ class MemberDef : public Definition
     MemberDef *categoryRelation() const;
 
     QCString displayName(bool=TRUE) const;
+    QCString getDeclType() const;
+    void getLabels(QStrList &sl,Definition *container) const;
+
+    const ArgumentList *typeConstraints() const;
+
+    // overrules
+    QCString documentation() const;
+    QCString briefDescription(bool abbr=FALSE) const;
+
+
 
     //-----------------------------------------------------------------------------------
     // ----  setters -----
@@ -382,7 +395,7 @@ class MemberDef : public Definition
     void _computeLinkableInProject();
     void _computeIsConstructor();
     void _computeIsDestructor();
-    void _getLabels(QStrList &sl,Definition *container) const;
+    void _writeGroupInclude(OutputList &ol,bool inGroup);
     void _writeCallGraph(OutputList &ol);
     void _writeCallerGraph(OutputList &ol);
     void _writeReimplements(OutputList &ol);
