@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: membergroup.h,v 1.13 2001/03/19 19:27:41 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -61,8 +61,8 @@ class MemberGroup
                MemberListType lt,
                ClassDef *inheritedFrom,const QCString &inheritId);
 
-    QCString documentation() { return doc; }
-    bool allMembersInSameSection() { return inSameSection; }
+    QCString documentation() const { return doc; }
+    bool allMembersInSameSection() const { return inSameSection; }
     void addToDeclarationSection();
     int countDecMembers(GroupDef *gd=0);
     int countDocMembers();
