@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: memberlist.cpp,v 1.35 2001/03/19 19:27:41 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -315,7 +315,7 @@ void MemberList::writePlainDeclarations(OutputList &ol,
     return; // no members in this list
   }
   //printf("  --> writePlainDeclaration() numDecMembers()=%d\n",
-  //     numDecMembers());
+  //    numDecMembers());
   
   ol.pushGeneratorState();
 
@@ -329,6 +329,7 @@ void MemberList::writePlainDeclarations(OutputList &ol,
     if ((inheritedFrom==0 || !md->isReimplementedBy(inheritedFrom)) &&
         md->isBriefSectionVisible())
     {
+      //printf(">>> rendering\n");
       switch(md->memberType())
       {
         case MemberType_Define:    // fall through
@@ -488,12 +489,13 @@ void MemberList::writePlainDeclarations(OutputList &ol,
  *  @param inheritedFrom if not 0, the list is shown inside the
  *         given class as inherited members, parameter cd points to the
  *         class containing the members.
+ *  @param lt Type of list that is inherited from.
  */
 void MemberList::writeDeclarations(OutputList &ol,
              ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
              const char *title,const char *subtitle,
              const DefinitionIntf::DefType compoundType,bool showEnumValues,
-             bool showInline,ClassDef *inheritedFrom)
+             bool showInline,ClassDef *inheritedFrom,MemberListType lt)
 {
   (void)showEnumValues; // unused
 
@@ -507,8 +509,8 @@ void MemberList::writeDeclarations(OutputList &ol,
   if (ctx==0 && gd) ctx = gd;
   if (ctx==0 && fd) ctx = fd;
 
-  //printf("%p: MemberList::writeDeclaration(title=`%s',subtitle=`%s')=%d\n",
-  //       this,title,subtitle,numDecMembers());
+  //printf("%p: MemberList::writeDeclaration(title=`%s',subtitle=`%s')=%d inheritedFrom=%p\n",
+  //       this,title,subtitle,numDecMembers(),inheritedFrom);
 
   int num = numDecMembers();
   if (inheritedFrom)
@@ -519,7 +521,7 @@ void MemberList::writeDeclarations(OutputList &ol,
     {
       ol.pushGeneratorState();
       ol.disableAllBut(OutputGenerator::Html);
-      inheritId = substitute(listTypeAsString(),"-","_")+"_"+
+      inheritId = substitute(listTypeAsString(lt),"-","_")+"_"+
                   stripPath(cd->getOutputFileBase());
       if (title)
       {
@@ -540,7 +542,7 @@ void MemberList::writeDeclarations(OutputList &ol,
       }
       else
       {
-        ol.startMemberHeader(listTypeAsString());
+        ol.startMemberHeader(listTypeAsString(m_listType));
       }
       ol.parseText(title);
       if (showInline)
@@ -872,9 +874,14 @@ void MemberList::unmarshal(StorageIntf *s)
   }
 }
 
-QCString MemberList::listTypeAsString() const
+void MemberList::setNeedsSorting(bool b)
 {
-  switch(m_listType)
+  m_needsSorting = b;
+}
+
+QCString MemberList::listTypeAsString(MemberListType type) 
+{
+  switch(type)
   {
     case MemberListType_pubMethods: return "pub-methods";
     case MemberListType_proMethods: return "pro-methods";
@@ -928,10 +935,6 @@ QCString MemberList::listTypeAsString() const
   return "";
 }
 
-void MemberList::setNeedsSorting(bool b)
-{
-  m_needsSorting = b;
-}
 
 //--------------------------------------------------------------------------
 
