@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: message.h,v 1.8 2001/03/19 19:27:41 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -29,4 +29,5 @@ extern void warn_uncond(const char *fmt, ...);
 extern void err(const char *fmt, ...);
 void initWarningFormat();
 
+extern void printlex(int dbg, bool enter, const char *lexName, const char *fileName);
 #endif
