@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: msc.cpp,v 1.14 2001/03/19 19:27:40 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -22,13 +22,13 @@
 #include "docparser.h"
 #include "doxygen.h"
 #include "util.h"
+#include "ftextstream.h"
 
-#include <qtextstream.h>
 #include <qdir.h>
 
 static const int maxCmdLine = 40960;
 
-static bool convertMapFile(QTextStream &t,const char *mapName,const QCString relPath,
+static bool convertMapFile(FTextStream &t,const char *mapName,const QCString relPath,
                            const QCString &context)
 {
   QFile f(mapName);
@@ -55,7 +55,7 @@ static bool convertMapFile(QTextStream &t,const char *mapName,const QCString rel
       // obtain the url and the coordinates in the order used by graphviz-1.5
       sscanf(buf,"rect %s %d,%d %d,%d",url,&x1,&y1,&x2,&y2);
 
-      if ( strcmp(url,"\\ref") == 0 )
+      if (qstrcmp(url,"\\ref")==0 || qstrcmp(url,"@ref")==0)
       {
         isRef = TRUE;
         sscanf(buf,"rect %s %s %d,%d %d,%d",ref,url,&x1,&y1,&x2,&y2);
@@ -103,15 +103,22 @@ void writeMscGraphFromFile(const char *inFile,const char *outDir,
   QCString mscExe = Config_getString("MSCGEN_PATH")+"mscgen"+portable_commandExtension();
   QCString mscArgs;
   QCString extension;
-  if (format==MSC_BITMAP)
+  switch (format)
   {
-    mscArgs+="-T png";
-    extension=".png";
-  }
-  else if (format==MSC_EPS)
-  {
-    mscArgs+="-T eps";
-    extension=".eps";
+    case MSC_BITMAP:
+      mscArgs+="-T png";
+      extension=".png";
+      break;
+    case MSC_EPS:
+      mscArgs+="-T eps";
+      extension=".eps";
+      break;
+    case MSC_SVG:
+      mscArgs+="-T svg";
+      extension=".svg";
+      break;
+    default:
+      goto error; // I am not very fond of goto statements, but when in Rome...
   }
   mscArgs+=" -i \"";
   mscArgs+=inFile;
@@ -175,8 +182,8 @@ QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
   }
   portable_sysTimerStop();
   
-  QString result;
-  QTextOStream tmpout(&result);
+  QGString result;
+  FTextStream tmpout(&result);
   convertMapFile(tmpout, outFile, relPath, context);
   QDir().remove(outFile);
 
@@ -188,11 +195,28 @@ void writeMscImageMapFromFile(FTextStream &t,const QCString &inFile,
                               const QCString &outDir,
                               const QCString &relPath,
                               const QCString &baseName,
-                              const QCString &context)
+                              const QCString &context,
+			      MscOutputFormat format
+ 			    )
 {
   QCString mapName = baseName+".map";
   QCString mapFile = inFile+".map";
-  t << "<img src=\"" << relPath << baseName << ".png\" alt=\""
+  t << "<img src=\"" << relPath << baseName << ".";
+  switch (format)
+  {
+    case MSC_BITMAP:
+      t << "png";
+      break;
+    case MSC_EPS:
+      t << "eps";
+      break;
+    case MSC_SVG:
+      t << "svg";
+      break;
+    default:
+      t << "unknown";
+  }
+  t << "\" alt=\""
     << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\"/>" << endl;
   QCString imap = getMscImageMapFromFile(inFile,outDir,relPath,context);
   t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
