@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: msc.h,v 1.14 2001/03/19 19:27:40 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -21,7 +21,7 @@
 class QCString;
 class FTextStream;
 
-enum MscOutputFormat { MSC_BITMAP , MSC_EPS };
+enum MscOutputFormat { MSC_BITMAP , MSC_EPS, MSC_SVG };
 
 void writeMscGraphFromFile(const char *inFile,const char *outDir,
                            const char *outFile,MscOutputFormat format);
@@ -31,7 +31,9 @@ QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
 
 void writeMscImageMapFromFile(FTextStream &t,const QCString &inFile,
                               const QCString &outDir, const QCString &relPath,
-                              const QCString &baseName, const QCString &context);
+                              const QCString &baseName, const QCString &context,
+			      MscOutputFormat format
+ 			    );
 
 #endif
 
