@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: namespacedef.h,v 1.18 2001/03/19 19:27:41 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -22,6 +22,7 @@
 #include <qdict.h>
 #include "sortdict.h"
 #include "definition.h"
+#include "filedef.h"
 
 class MemberList;
 class ClassDef;
@@ -45,7 +46,7 @@ class NamespaceDef : public Definition
     DefType definitionType() const { return TypeNamespace; }
     QCString getOutputFileBase() const;
     QCString anchor() const { return QCString(); }
-    void insertUsedFile(const char *fname);
+    void insertUsedFile(FileDef *fd);
     
     void writeDocumentation(OutputList &ol);
     void writeMemberPages(OutputList &ol);
@@ -92,6 +93,8 @@ class NamespaceDef : public Definition
     /*! Returns the namespaces contained in this namespace */
     NamespaceSDict *getNamespaceSDict() const { return namespaceSDict; }
 
+    QCString title() const;
+
     bool visited;
 
   private:
@@ -115,7 +118,7 @@ class NamespaceDef : public Definition
     void addNamespaceAttributes(OutputList &ol);
 
     QCString              fileName;
-    QStrList              files;
+    FileList              files;
 
     NamespaceSDict       *usingDirList;
     SDict<Definition>    *usingDeclList;
