@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: pycode.h,v 1.9 2001/03/19 19:27:39 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -25,16 +25,19 @@
 #ifndef PYCODE_H
 #define PYCODE_H
 
+#include "types.h"
+
 class CodeOutputInterface;
 class FileDef;
 class MemberDef;
 class QCString;
 class Definition;
 
-extern void parsePythonCode(CodeOutputInterface &,const char *,const QCString &, 
+extern void parsePythonCode(CodeOutputInterface &,const char *,const QCString &,
              bool ,const char *,FileDef *fd,
 	     int startLine,int endLine,bool inlineFragment,
-             MemberDef *memberDef,bool showLineNumbers,Definition *searchCtx);
+             MemberDef *memberDef,bool showLineNumbers,Definition *searchCtx,
+             bool collectXRefs);
 extern void resetPythonCodeParserState();
 
 #endif
