@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: pyscanner.h,v 1.9 2001/03/19 19:27:39 root Exp $
+ * 
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
@@ -46,6 +46,7 @@ class PythonLanguageScanner : public ParserInterface
     void parseCode(CodeOutputInterface &codeOutIntf,
                    const char *scopeName,
                    const QCString &input,
+                   SrcLangExt lang,
                    bool isExampleBlock,
                    const char *exampleName=0,
                    FileDef *fileDef=0,
@@ -54,7 +55,8 @@ class PythonLanguageScanner : public ParserInterface
                    bool inlineFragment=FALSE,
                    MemberDef *memberDef=0,
                    bool showLineNumbers=TRUE,
-                   Definition *searchCtx=0
+                   Definition *searchCtx=0,
+                   bool collectXrefs=TRUE
                   );
     void resetCodeParserState();
     void parsePrototype(const char *text);
