@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -106,6 +106,8 @@ class TextDocVisitor : public DocVisitor
 
     void visitPre(DocMscFile *) {}
     void visitPost(DocMscFile *) {}
+    void visitPre(DocDiaFile *) {}
+    void visitPost(DocDiaFile *) {}
     void visitPre(DocLink *) {}
     void visitPost(DocLink *) {}
     void visitPre(DocRef *) {}
@@ -130,6 +132,8 @@ class TextDocVisitor : public DocVisitor
     void visitPost(DocHtmlBlockQuote *) {}
     void visitPre(DocVhdlFlow *) {}
     void visitPost(DocVhdlFlow *) {}
+    void visitPre(DocParBlock *) {}
+    void visitPost(DocParBlock *) {}
 
   private:
 
