@@ -1,12 +1,12 @@
 /******************************************************************************
  *
- * 
+ *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -33,13 +33,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString latexLanguageSupportCommand()
     {
         return "<pre>\\usepackage[latin]{armtex}\n"
-			   "\\usepackage[armscii8]{inputenc}\n</pre>"; 
-    }
-
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-        return "utf-8"; 
+			   "\\usepackage[armscii8]{inputenc}\n</pre>";
     }
 
     // --- Language translation methods -------------------
@@ -132,7 +126,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 
     // quick reference sections
 
-    /*! This is put above each page as a link to the list of all groups of 
+    /*! This is put above each page as a link to the list of all groups of
      *  compounds or files (see the \\group command).
      */
     virtual QCString trModules()
@@ -178,11 +172,11 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Գլոբալներ"; 
+        return "Գլոբալներ";
       }
       else
       {
-        return "Ֆայլի անդամներ"; 
+        return "Ֆայլի անդամներ";
       }
     }
 
@@ -291,26 +285,26 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trModulesDescription()
     { return "Բոլոր մոդուլների ցուցակը."; }
 
-    // index titles (the project name is prepended for these) 
+    // index titles (the project name is prepended for these)
 
 
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
     { return " - Փաստագրություն"; }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      * index of all groups.
      */
     virtual QCString trModuleIndex()
     { return "Մոդուլներ"; }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      * class hierarchy.
      */
     virtual QCString trHierarchicalIndex()
     { return "Դասակարգումներ"; }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      * annotated compound index.
      */
     virtual QCString trCompoundIndex()
@@ -374,43 +368,37 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trReferenceManual()
     { return "Հղումների ձեռնարկ"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of defines
      */
     virtual QCString trDefines()
     { return "Մակրոսներ"; }
 
-    /*! This is used in the documentation of a file as a header before the 
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Ֆունկցիաների նախատիպեր"; }
-
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
     virtual QCString trTypedefs()
     { return "Տիպի սահմանումներ (typedef)"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of enumerations
      */
     virtual QCString trEnumerations()
     { return "Համարակալումներ"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of (global) functions
      */
     virtual QCString trFunctions()
     { return "Ֆունկցիաներ"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of (global) variables
      */
     virtual QCString trVariables()
     { return "Փոփոխականներ"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of (global) variables
      */
     virtual QCString trEnumerationValues()
@@ -422,37 +410,31 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trDefineDocumentation()
     { return "Մակրոսներ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Ֆունկցիաների նախատիպեր"; }
-
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
     virtual QCString trTypedefDocumentation()
     { return "Տիպի սահմանումներ (typedef)"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for enumeration types
      */
     virtual QCString trEnumerationTypeDocumentation()
     { return "Համարակալման տիպեր"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
      */
     virtual QCString trFunctionDocumentation()
     { return "Ֆունկցիաներ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for variables
      */
     virtual QCString trVariableDocumentation()
     { return "Փոփոխականներ"; }
 
-    /*! This is used in the documentation of a file/namespace/group before 
+    /*! This is used in the documentation of a file/namespace/group before
      *  the list of links to documented compounds
      */
     virtual QCString trCompounds()
@@ -462,31 +444,24 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
         return "Տվյալների կառուցվածք";
       }
       else
-      { 
+      {
         return "Դասեր";
       }
-
     }
 
-    /*! This is used in the documentation of a group before the list of 
+    /*! This is used in the documentation of a group before the list of
      *  links to documented files
      */
-    /*! This is used in the standard footer of each page and indicates when 
-     *  the page was generated 
+    /*! This is used in the standard footer of each page and indicates when
+     *  the page was generated
      */
     virtual QCString trGeneratedAt(const char *date,const char *projName)
-    { 
+    {
       QCString result=(QCString)"Ստեղծվել է "+date;
       if (projName) result+=projName+QCString(" -ի համար,");
       result+=(QCString)" հետևյալ համակարգով.";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return "Հեղինակ - ";
-    }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
@@ -529,11 +504,11 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     /*! this text is used in the title page of a LaTeX document. */
     virtual QCString trGeneratedBy()
     { return "Ստեղծված է հետևյալ համակարգի կողմից"; }
-    
+
 //////////////////////////////////////////////////////////////////////////
-// new since 0.49-990307 
+// new since 0.49-990307
 //////////////////////////////////////////////////////////////////////////
-    
+
     /*! used as the title of page containing all the index of all namespaces. */
     virtual QCString trNamespaceList()
     { return "Անունների տարածությունների ցուցակ"; }
@@ -556,13 +531,13 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990405
 //////////////////////////////////////////////////////////////////////////
-    
+
     /*! used in the class documentation as a header before the list of all
-     * related classes 
+     * related classes
      */
     virtual QCString trRelatedFunctionDocumentation()
     { return "Դասի ընկերներ և կապված ֆունկցիաներ"; }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990425
 //////////////////////////////////////////////////////////////////////////
@@ -574,7 +549,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     {
       QCString result=(QCString)clName;
       if (isTemplate)
-      {		  
+      {
         switch(compType)
         {
           case ClassDef::Class:      result+=" Դասի"; break;
@@ -618,7 +593,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       result+=" անունների տարածություններ";
       return result;
     }
-    
+
     virtual QCString trPublicMembers()
     { return "Բաց անդամ ֆունկցիաներ"; }
     virtual QCString trPublicSlots()
@@ -639,7 +614,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     { return "Փակ սլոթեր"; }
     virtual QCString trStaticPrivateMembers()
     { return "Փակ ստատիկ անդամ ֆունկցիաներ"; }
-    
+
     /*! this function is used to produce a comma-separated list of items.
      *  use generateMarker(i) to indicate where item i should be put.
      */
@@ -648,23 +623,23 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       QCString result;
       int i;
       // the inherits list contain `numEntries' classes
-      for (i=0;i<numEntries;i++) 
+      for (i=0;i<numEntries;i++)
       {
         // use generateMarker to generate placeholders for the class links!
-        result+=generateMarker(i); // generate marker for entry i in the list 
+        result+=generateMarker(i); // generate marker for entry i in the list
                                    // (order is left to right)
-        
+
         if (i!=numEntries-1)  // not the last entry, so we need a separator
         {
-          if (i<numEntries-2) // not the fore last entry 
+          if (i<numEntries-2) // not the fore last entry
             result+=", ";
           else                // the fore last entry
             result+=" և ";
         }
       }
-      return result; 
+      return result;
     }
-    
+
     /*! used in class documentation to produce a list of base classes,
      *  if class diagrams are disabled.
      */
@@ -681,7 +656,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       return "Ժառանգորդ դասեր - "+trWriteList(numEntries)+":";
     }
 
-    /*! used in member documentation blocks to produce a list of 
+    /*! used in member documentation blocks to produce a list of
      *  members that are hidden by this one.
      */
     virtual QCString trReimplementedFromList(int numEntries)
@@ -708,14 +683,14 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       if (!extractAll) result+="փաստագրված ";
       result+="անունների տարածության անդամների ցուցակը` "
 			"հղումներով դեպի ";
-      if (extractAll) 
+      if (extractAll)
         result+="բոլոր անդամների անունների տարածության փաստագրությունը.";
-      else 
+      else
         result+="անունների տարածությունը, որին նրանք պատկանում են.";
       return result;
     }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      *  index of all namespaces.
      */
     virtual QCString trNamespaceIndex()
@@ -746,7 +721,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
      */
     virtual QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
         bool single)
-    { 
+    {
       QCString result = (QCString)"Այս ";
       switch(compType)
       {
@@ -764,12 +739,6 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Այբբենական ցուցակ"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -783,7 +752,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trMainPage()
     { return "Գլխավոր էջ"; }
 
-    /*! This is used in references to page that are put in the LaTeX 
+    /*! This is used in references to page that are put in the LaTeX
      *  documentation. It should be an abbreviation of the word page.
      */
     virtual QCString trPageAbbreviation()
@@ -828,7 +797,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
     {
-      return "Կառուցիչներ"; 
+      return "Կառուցիչներ";
     }
     /*! Used in the file documentation to point to the corresponding sources. */
     virtual QCString trGotoSourceCode()
@@ -885,7 +854,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 // new since 1.1.0
 //////////////////////////////////////////////////////////////////////////
-    
+
     virtual QCString trNote()
     {
       return "Նշում";
@@ -978,7 +947,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     {
       return "Սկսած";
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.1.5
 //////////////////////////////////////////////////////////////////////////
@@ -988,12 +957,12 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     {
       return "Լեգենդ";
     }
-    /*! page explaining how the dot graph's should be interpreted 
+    /*! page explaining how the dot graph's should be interpreted
      *  The %A in the text below are to prevent link to classes called "A".
      */
     virtual QCString trLegendDocs()
     {
-      return 
+      return
 		"Այս էջը նկարագրում է, թե ինչպես մեկնաբանել doxygen-ի ստեղծած գրաֆները:<p>\n"
         "Դիտարկենք հետևյալ օրինակը.\n"
         "\\code\n"
@@ -1059,7 +1028,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.0
 //////////////////////////////////////////////////////////////////////////
-    
+
     /*! Used as a marker that is put before a test item */
     virtual QCString trTest()
     {
@@ -1071,16 +1040,6 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       return "Թեստերի ցուցակ";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "DCOP անդամ ֆունկցիաներ";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1141,7 +1100,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.5
 //////////////////////////////////////////////////////////////////////////
-    
+
     /*! Used as a marker that is put before a \\bug item */
     virtual QCString trBug()
     {
@@ -1173,15 +1132,15 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trClass(bool first_capital, bool singular)
-    { 
+    {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
         QCString result((first_capital ? "Տվյալների կառուցվածք" : "տվյալների կառուցվածք"));
-        return result; 
+        return result;
       }
       else
       {
@@ -1192,69 +1151,69 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trFile(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Ֆայլ" : "ֆայլ"));
       if (!singular)  result+="եր";
-      return result; 
+      return result;
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trNamespace(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Անունների տարածություն" : "անունների տարածություն"));
       if (!singular)  result+="ներ";
-      return result; 
+      return result;
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trGroup(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Խ" : "խ"));
       result+=(singular ? "ումբ" : "մբեր");
-      return result; 
+      return result;
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trPage(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Էջ" : "էջ"));
       if (!singular)  result+="եր";
       return result;
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trMember(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Անդամ" : "անդամ"));
       if (!singular)  result+="ներ";
-      return result; 
+      return result;
     }
-   
+
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trGlobal(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Գլոբալ" : "գլոբալ"));
       if (!singular)  result+="ներ";
-      return result; 
+      return result;
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1264,7 +1223,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     /*! This text is generated when the \\author command is used and
      *  for the author section in man pages. */
     virtual QCString trAuthor(bool first_capital, bool singular)
-    {                                                                         
+    {
       QCString result((first_capital ? "Հեղինակ" : "հեղինակ"));
       if (!singular) result+="ներ";
       return result;
@@ -1285,7 +1244,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 // new since 1.2.13
 //////////////////////////////////////////////////////////////////////////
 
-    /*! used in member documentation blocks to produce a list of 
+    /*! used in member documentation blocks to produce a list of
      *  members that are implemented by this one.
      */
     virtual QCString trImplementedFromList(int numEntries)
@@ -1317,8 +1276,8 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 // new since 1.2.17
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used as the header of the list of item that have been 
-     *  flagged deprecated 
+    /*! Used as the header of the list of item that have been
+     *  flagged deprecated
      */
     virtual QCString trDeprecatedList()
     {
@@ -1329,7 +1288,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 // new since 1.2.18
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used as a header for declaration section of the events found in 
+    /*! Used as a header for declaration section of the events found in
      * a C# program
      */
     virtual QCString trEvents()
@@ -1349,43 +1308,43 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     /*! Used as a heading for a list of Java class types with package scope.
      */
     virtual QCString trPackageTypes()
-    { 
+    {
       return "Փաթեթի տիպեր";
     }
-    /*! Used as a heading for a list of Java class functions with package 
-     * scope. 
+    /*! Used as a heading for a list of Java class functions with package
+     * scope.
      */
     virtual QCString trPackageMembers()
-    { 
+    {
       return "Փաթեթի ֆունկցիաներ";
     }
-    /*! Used as a heading for a list of static Java class functions with 
+    /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
     virtual QCString trStaticPackageMembers()
-    { 
+    {
       return "Փաթեթի ստատիկ ֆունկցիաներ";
     }
-    /*! Used as a heading for a list of Java class variables with package 
+    /*! Used as a heading for a list of Java class variables with package
      * scope.
      */
     virtual QCString trPackageAttribs()
-    { 
+    {
       return "Փաթեթի ատրիբուտներ";
     }
-    /*! Used as a heading for a list of static Java class variables with 
+    /*! Used as a heading for a list of static Java class variables with
      * package scope.
      */
     virtual QCString trStaticPackageAttribs()
-    { 
+    {
       return "Փաթեթի ստատիկ ատրիբուտներ";
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3.1
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used in the quick index of a class/file/namespace member list page 
+    /*! Used in the quick index of a class/file/namespace member list page
      *  to link to the unfiltered list of all members.
      */
     virtual QCString trAll()
@@ -1402,14 +1361,6 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header 
-     *  of each page before the field where one can enter the text to search 
-     *  for. 
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Որոնում";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1421,7 +1372,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
      *  text can be different depending on the number of documents found.
      *  Inside the text you can put the special marker $num to insert
      *  the number representing the actual number of search results.
-     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the
      *  value 2 represents 2 or more matches. HTML markup is allowed inside
      *  the returned string.
      */
@@ -1435,13 +1386,13 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       {
         return "Հայտնաբերվել է 1 փաստաթուղթ:";
       }
-      else 
+      else
       {
         return "Հայտնաբերվել է <b>$num</b> փաստաթուղթ:"
           "Փաստաթղթերը դասակարգված են ըստ համապասխանության";
       }
     }
-    /*! This string is put before the list of matched words, for each search 
+    /*! This string is put before the list of matched words, for each search
      *  result. What follows is the list of words that matched the query.
      */
     virtual QCString trSearchMatches()
@@ -1482,12 +1433,12 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trDirectories()
     { return "Ֆայլադրաններ"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy. 
+    /*! This returns a sentences that introduces the directory hierarchy.
      *  and the fact that it is sorted alphabetically per level
      */
     virtual QCString trDirDescription()
     { return "Այս ֆայլադարանների հիերարխիան կարգավորված է կոպտորեն, "
-			"բայց ոչ ամբողջապես, այբբենական կարգով."; 
+			"բայց ոչ ամբողջապես, այբբենական կարգով.";
 	}
 
     /*! This returns the title of a directory page. The name of the
@@ -1500,10 +1451,10 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
      *  (\a first_capital) and in sigular or plural form (\a singular).
      */
     virtual QCString trDir(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Ֆայլադարան" : "ֆայլադարան"));
       if (!singular) result+="ներ";
-      return result; 
+      return result;
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1529,7 +1480,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       return "Այս ֆունկցիայի կանչերի գրաֆը.";
     }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for enumeration values
      */
     virtual QCString trEnumerationValueDocumentation()
@@ -1543,7 +1494,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trMemberFunctionDocumentationFortran()
     { return "Անդամ ֆունցիաներ/ենթածրագրեր"; }
 
-    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */
     virtual QCString trCompoundListFortran()
     { return "Տվյալների տիպերի ցուցակը"; }
 
@@ -1564,18 +1515,18 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
         result+="փաստագրված ";
       }
       result+="տվյալների տիպերի անդամների ցուցակը` հղումներով դեպի ";
-      if (!extractAll) 
+      if (!extractAll)
       {
 		result+="բոլոր անդամների տվյալների կառուցվածքի փաստագրությունը";
       }
-      else 
+      else
       {
         result+="տվյալների տիպերը, որոնց նրանք պատկանում են";
       }
       return result;
     }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      * annotated compound index (Fortran).
      */
     virtual QCString trCompoundIndexFortran()
@@ -1587,24 +1538,24 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trTypeDocumentation()
     { return "Տվյալների տիպեր"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of (global) subprograms (Fortran).
      */
     virtual QCString trSubprograms()
     { return "Ֆունկցիաներ/ենթածրագրեր"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for subprograms (Fortran)
      */
     virtual QCString trSubprogramDocumentation()
     { return "Ֆունկցիաներ/ենթածրագրեր"; }
 
-    /*! This is used in the documentation of a file/namespace/group before 
+    /*! This is used in the documentation of a file/namespace/group before
      *  the list of links to documented compounds (Fortran)
      */
      virtual QCString trDataTypes()
     { return "Տվյալների տիպեր"; }
-    
+
     /*! used as the title of page containing all the index of all modules (Fortran). */
     virtual QCString trModulesList()
     { return "Մոդուլների ցուցակ"; }
@@ -1624,7 +1575,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
                                     bool isTemplate)
     {
       QCString result=(QCString)clName;
-      if (!isTemplate) 
+      if (!isTemplate)
       {
         switch(compType)
         {
@@ -1660,43 +1611,43 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     {
       return QCString("Մոդուլ ") + namespaceName;
     }
-    
+
     /*! This is put above each page as a link to all members of modules. (Fortran) */
     virtual QCString trModulesMembers()
     { return "Մոդուլի անդամներ"; }
 
     /*! This is an introduction to the page with all modules members (Fortran) */
     virtual QCString trModulesMemberDescription(bool extractAll)
-    { 
+    {
       QCString result="Մոդուլի բոլոր ";
       if (!extractAll) result+="փաստագրված ";
       result+="անդամների ցուցակը` հղումներով դեպի ";
-      if (extractAll) 
+      if (extractAll)
       {
         result+="բոլոր անդամների փաստագրությունները.";
       }
-      else 
+      else
       {
         result+="մոդուլները, որոնց նրանք պատկանում են.";
       }
       return result;
     }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      *  index of all modules (Fortran).
      */
     virtual QCString trModulesIndex()
     { return "Մոդուլներ"; }
-    
+
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trModule(bool first_capital, bool singular)
-    {       
+    {
       QCString result((first_capital ? "Մոդուլ" : "մոդուլ"));
-      if (!singular)  result+="ներ"; 
-      return result; 
+      if (!singular)  result+="ներ";
+      return result;
     }
     /*! This is put at the bottom of a module documentation page and is
      *  followed by a list of files that were used to generate the page.
@@ -1722,24 +1673,24 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       return result;
     }
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trType(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Տիպ" : "տիպ"));
       if (!singular)  result+="եր";
-      return result; 
+      return result;
     }
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trSubprogram(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Ե" : "ե"));
-      if (singular)  result+="նթածրագիր"; else result+="նթածրագրեր"; 
-      return result; 
+      if (singular)  result+="նթածրագիր"; else result+="նթածրագրեր";
+      return result;
     }
 
     /*! C# Type Constraint list */
@@ -1785,12 +1736,6 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)name + " -ի կախվածությունների գծագիր";
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
