@@ -42,7 +42,7 @@
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
 */
-class TranslatorEsperanto : public TranslatorAdapter_1_8_2
+class TranslatorEsperanto : public TranslatorAdapter_1_8_4
 {
   public:
 
@@ -76,12 +76,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
       return "\\usepackage[esperanto]{babel}\n";
     }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-      return "utf-8";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -424,12 +418,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
     virtual QCString trDefines()
     { return "Difinoj"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Funkciaj Prototipoj"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -466,12 +454,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
     virtual QCString trDefineDocumentation()
     { return "Difina Dokumentado"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Dokumentado de Funkciaj Prototipoj"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -521,12 +503,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
       result+=(QCString)" de";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return "skribita de";
-    }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
@@ -789,12 +765,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Alfabeta Listo"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1094,16 +1064,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
       return "Testa Listo";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "DCOP Membraj Funkcioj";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1447,14 +1407,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Serĉi";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1819,12 +1771,6 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Diagramo de dependecoj dosierujaj por "+name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
@@ -1877,7 +1823,7 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
       }
       return sdate;
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
 //////////////////////////////////////////////////////////////////////////
@@ -1926,8 +1872,8 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
     virtual QCString trInheritedFrom(const char *members,const char *what)
     { return QCString(members)+" heredita el "+what; }
 
-    /*! Header of the sections with inherited members specific for the 
-     *  base class(es) 
+    /*! Header of the sections with inherited members specific for the
+     *  base class(es)
      */
     virtual QCString trAdditionalInheritedMembers()
     { return "Kromaj Hereditaj Membroj"; }
@@ -1937,7 +1883,7 @@ class TranslatorEsperanto : public TranslatorAdapter_1_8_2
 //////////////////////////////////////////////////////////////////////////
 
     /*! Used as a tooltip for the toggle button that appears in the
-     *  navigation tree in the HTML output when GENERATE_TREEVIEW is 
+     *  navigation tree in the HTML output when GENERATE_TREEVIEW is
      *  enabled. This tooltip explains the meaning of the button.
      */
     virtual QCString trPanelSynchronisationTooltip(bool enable)
