@@ -11,7 +11,7 @@
  * input used in their production; they are not affected by this license.
  *
  * Portuguese translation version 20110428
- *    Maintainer (from 04/28/2011): 
+ *    Maintainer (from 04/28/2011):
  *       Fabio "FJTC" Jun Takada Chino <jun-chino at uol.com.br>
  *    Maintainer (until 04/28/2011):
  *       Rui Godinho Lopes <rui at ruilopes.com>
@@ -25,10 +25,10 @@
  * ---------------
  * History:
  * 20110628:
- *	- Updated to 1.7.5; 
+ *	- Updated to 1.7.5;
  *      - All obsolete methods have been removed;
  * 20110428
- *   - Updated to doxygen 1.6.3 using the Brazilian Portuguese as the base. 
+ *   - Updated to doxygen 1.6.3 using the Brazilian Portuguese as the base.
  *     Requires revision by a Portuguese (Portugal native speaker);
  * 007 09 june 2003
  *   ! Updated for doxygen v1.3.1
@@ -58,18 +58,18 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
 
     // --- Language control methods -------------------
 
-    /*! Used for identification of the language. The identification 
-     * should not be translated. It should be replaced by the name 
+    /*! Used for identification of the language. The identification
+     * should not be translated. It should be replaced by the name
      * of the language in English using lower-case characters only
-     * (e.g. "czech", "japanese", "russian", etc.). It should be equal to 
+     * (e.g. "czech", "japanese", "russian", etc.). It should be equal to
      * the identification used in language.cpp.
      */
     QCString idLanguage()
     { return "portuguese"; }
 
-    /*! Used to get the LaTeX command(s) for the language support. 
+    /*! Used to get the LaTeX command(s) for the language support.
      *  This method should return string with commands that switch
-     *  LaTeX to the desired language.  For example 
+     *  LaTeX to the desired language.  For example
      *  <pre>"\\usepackage[german]{babel}\n"
      *  </pre>
      *  or
@@ -77,17 +77,13 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
      *  "\\usepackage[latin2]{inputenc}\n"
      *  "\\usepackage[T1]{fontenc}\n"
      *  </pre>
-     * 
+     *
      * The English LaTeX does not use such commands.  Because of this
      * the empty string is returned in this implementation.
      */
     virtual QCString latexLanguageSupportCommand()
     { return "Portuguese"; }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    { return "utf-8"; }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -119,7 +115,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Documentação dos campos e atributos"; 
+        return "Documentação dos campos e atributos";
       }
       else
       {
@@ -251,7 +247,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
 
     /*! This is an introduction to the annotated compound list. */
     QCString trCompoundListDescription()
-    {       
+    {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
         return "Lista das estruturas de dados com uma breve descrição:";
@@ -279,7 +275,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
         result+=" documentadas";
       }
       result+=" com referência para ";
-      if (!extractAll) 
+      if (!extractAll)
       {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
@@ -290,7 +286,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
           result+="a documentação de cada membro:";
         }
       }
-      else 
+      else
       {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
@@ -319,9 +315,9 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
         if (!extractAll) result+="documentados ";
       }
       result+="com referência para ";
-      if (extractAll) 
+      if (extractAll)
         result+="o ficheiro a que pertecem:";
-      else 
+      else
         result+="a respectiva documentação:";
       return result;
     }
@@ -363,7 +359,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     QCString trCompoundIndex()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-      { 
+      {
         return "Índice das estruturas de dados";
       }
       else
@@ -418,12 +414,6 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     QCString trDefines()
     { return "Macros"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    QCString trFuncProtos()
-    { return "Protótipos de funções"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -460,12 +450,6 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     QCString trDefineDocumentation()
     { return "Documentação das macros"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    QCString trFunctionPrototypeDocumentation()
-    { return "Documentação dos protótipos de funções"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -515,12 +499,6 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       result+=(QCString)" por";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    QCString trWrittenBy()
-    {
-      return "escrito por";
-    }
 
     /*! this text is put before a class diagram */
     QCString trClassDiagram(const char *clName)
@@ -787,15 +765,6 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    {
-      return "Lista alfabética";
-    }
-
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1088,16 +1057,6 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       return "Lista de teste";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "Métodos DCOP";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1324,7 +1283,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
 // new since 1.2.13
 //////////////////////////////////////////////////////////////////////////
 
-    /*! used in member documentation blocks to produce a list of 
+    /*! used in member documentation blocks to produce a list of
      *  members that are implemented by this one.
      */
     virtual QCString trImplementedFromList(int numEntries)
@@ -1368,7 +1327,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
 // new since 1.2.18
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used as a header for declaration section of the events found in 
+    /*! Used as a header for declaration section of the events found in
      * a C# program
      */
     virtual QCString trEvents()
@@ -1388,43 +1347,43 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     /*! Used as a heading for a list of Java class types with package scope.
      */
     virtual QCString trPackageTypes()
-    { 
+    {
       return "Tipos do Pacote";
     }
-    /*! Used as a heading for a list of Java class functions with package 
-     * scope. 
+    /*! Used as a heading for a list of Java class functions with package
+     * scope.
      */
     virtual QCString trPackageMembers()
-    { 
+    {
       return "Funções do Pacote";
     }
-    /*! Used as a heading for a list of static Java class functions with 
+    /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
     virtual QCString trStaticPackageMembers()
-    { 
+    {
       return "Funções Estáticas do Pacote";
     }
-    /*! Used as a heading for a list of Java class variables with package 
+    /*! Used as a heading for a list of Java class variables with package
      * scope.
      */
     virtual QCString trPackageAttribs()
-    { 
+    {
       return "Atributos do Pacote";
     }
-    /*! Used as a heading for a list of static Java class variables with 
+    /*! Used as a heading for a list of static Java class variables with
      * package scope.
      */
     virtual QCString trStaticPackageAttribs()
-    { 
+    {
       return "Atributos Estáticos do Pacote";
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3.1
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used in the quick index of a class/file/namespace member list page 
+    /*! Used in the quick index of a class/file/namespace member list page
      *  to link to the unfiltered list of all members.
      */
     virtual QCString trAll()
@@ -1436,19 +1395,11 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     {
       return "Grafo de chamadas desta função:";
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3.3 - Based on the Brazilian Portuguese Translation
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Procurar por";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1487,7 +1438,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     {
       return "Resultados:";
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3.8
 //////////////////////////////////////////////////////////////////////////
@@ -1521,7 +1472,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     virtual QCString trDirectories()
     { return "Diretórios"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy. 
+    /*! This returns a sentences that introduces the directory hierarchy.
      *  and the fact that it is sorted alphabetically per level
      */
     virtual QCString trDirDescription()
@@ -1541,10 +1492,10 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
      *  (\a first_capital) and in sigular or plural form (\a singular).
      */
     virtual QCString trDir(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Diretório" : "diretório"));
       if (!singular) result+="s";
-      return result; 
+      return result;
     }
 //////////////////////////////////////////////////////////////////////////
 // new since 1.4.1
@@ -1558,7 +1509,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
        return "Este é um método provido por conveniência. "
        		"Ele difere do método acima apenas na lista de "
        		"argumentos que devem ser utilizados.";
-    }    
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.4.6
@@ -1570,22 +1521,22 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       return "Este é o diagrama das funções que utilizam esta função:";
     }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for enumeration values
      */
     virtual QCString trEnumerationValueDocumentation()
     { return "Documentação da enumeração"; }
 
-  
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.5.4 (mainly for Fortran)
 //////////////////////////////////////////////////////////////////////////
-    
+
     /*! header that is put before the list of member subprograms (Fortran). */
     virtual QCString trMemberFunctionDocumentationFortran()
     { return "Documentação de Função Membro/Subrotina"; }
 
-    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */
     virtual QCString trCompoundListFortran()
     { return "Lista de Tipos de Dados"; }
 
@@ -1603,18 +1554,18 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       QCString result="Esta é a lista de todos os membros ";
       if (!extractAll) result+="documentados ";
       result+="dos tipos de dados com links para ";
-      if (extractAll) 
+      if (extractAll)
       {
         result+="a documentação dos tipos de dados para cada membro:";
       }
-      else 
+      else
       {
         result+="os tipos de dados a que pertencem:";
       }
       return result;
     }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      * annotated compound index (Fortran).
      */
     virtual QCString trCompoundIndexFortran()
@@ -1626,24 +1577,24 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
     virtual QCString trTypeDocumentation()
     { return "Documentação dos Tipos de Dados"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of (global) subprograms (Fortran).
      */
     virtual QCString trSubprograms()
     { return "Funções/Subrotinas"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for subprograms (Fortran)
      */
     virtual QCString trSubprogramDocumentation()
     { return "Documentação da Função/Subrotina"; }
 
-    /*! This is used in the documentation of a file/namespace/group before 
+    /*! This is used in the documentation of a file/namespace/group before
      *  the list of links to documented compounds (Fortran)
      */
      virtual QCString trDataTypes()
     { return "Tipos de Dados"; }
-    
+
     /*! used as the title of page containing all the index of all modules (Fortran). */
     virtual QCString trModulesList()
     { return "Lista de Módulos"; }
@@ -1665,7 +1616,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       QCString result = (QCString)"Referência ";
 
       if (isTemplate) result+="da Template ";
-      
+
       switch(compType)
       {
         case ClassDef::Class:      result+="do Modulo "; break;
@@ -1677,54 +1628,54 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
         case ClassDef::Exception:  result+="da Exceção "; break;
         default: break;
       }
-      result += clName; 
-     
+      result += clName;
+
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
     virtual QCString trModuleReference(const char *namespaceName)
     {
       QCString result = "Referência do Módulo ";
-      result += namespaceName;        
+      result += namespaceName;
       return result;
     }
-    
+
     /*! This is put above each page as a link to all members of modules. (Fortran) */
     virtual QCString trModulesMembers()
     { return "Membros do Módulo"; }
 
     /*! This is an introduction to the page with all modules members (Fortran) */
     virtual QCString trModulesMemberDescription(bool extractAll)
-    { 
+    {
       QCString result="Esta é a lista de todos os membros ";
       if (!extractAll) result+="documentados ";
       result+="dos módulos com links para ";
-      if (extractAll) 
+      if (extractAll)
       {
         result+="a documentação dos módulos para cada membro:";
       }
-      else 
+      else
       {
         result+="os módulos a que pertencem:";
       }
       return result;
     }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      *  index of all modules (Fortran).
      */
     virtual QCString trModulesIndex()
     { return "Índice dos Módulos"; }
-    
+
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trModule(bool first_capital, bool singular)
-    {       
+    {
       QCString result((first_capital ? "Modulo" : "modulo"));
       if (!singular)  result+="s";
-      return result; 
+      return result;
     }
     /*! This is put at the bottom of a module documentation page and is
      *  followed by a list of files that were used to generate the page.
@@ -1745,41 +1696,41 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
         case ClassDef::Exception:  result+="esta exceção "; break;
         default: break;
       }
-      
+
       result+=" foi gerada a partir do";
-      if (single) 
+      if (single)
     	result+=" seguinte ficheiro:";
       else
     	result+="s seguintes ficheiros:";
-      
+
       return result;
     }
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trType(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Tipo" : "tipo"));
       if (!singular)  result+="s";
-      return result; 
+      return result;
     }
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trSubprogram(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Subprograma" : "subprograma"));
       if (!singular)  result+="s";
-      return result; 
+      return result;
     }
 
     /*! C# Type Contraint list */
     virtual QCString trTypeConstraints()
     {
       return "Restrições do Tipo";
-    }    
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.6.0 (mainly for the new search engine)
@@ -1820,12 +1771,6 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Grafo de dependência de diretórios para " + name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
@@ -1844,7 +1789,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       return (QCString)"Inclui ficheiro em "+name;
     }
 
-    /** Compiles a date string. 
+    /** Compiles a date string.
      *  @param year Year in 4 digits
      *  @param month Month of the year: 1=January
      *  @param day Day of the Month: 1..31
@@ -1870,7 +1815,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
       }
       return sdate;
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
 //////////////////////////////////////////////////////////////////////////
@@ -1889,7 +1834,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_0
 
     /*! Header for the graph showing the directory dependencies */
     virtual QCString trDirDepGraph(const char *name)
-    { return QCString("Grafo de dependências do directório ")+name+":"; }       
+    { return QCString("Grafo de dependências do directório ")+name+":"; }
 };
 
 #endif
