@@ -75,12 +75,6 @@ class TranslatorRomanian : public Translator
       return "\\usepackage[romanian]{babel}\n";
     }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-      return "utf-8";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -435,12 +429,6 @@ class TranslatorRomanian : public Translator
     virtual QCString trDefines()
     { return "Definiţii"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Prototipuri de funcţii"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -477,12 +465,6 @@ class TranslatorRomanian : public Translator
     virtual QCString trDefineDocumentation()
     { return "Documentaţia definiţiilor"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Documentaţia prototipurilor de funcţii"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -533,12 +515,6 @@ class TranslatorRomanian : public Translator
       result+=(QCString)" de către";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return "scris de";
-    }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
@@ -803,12 +779,6 @@ class TranslatorRomanian : public Translator
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Listă Alfabetică"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1105,16 +1075,6 @@ class TranslatorRomanian : public Translator
       return "Listă de teste";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "Metode DCOP";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1458,14 +1418,6 @@ class TranslatorRomanian : public Translator
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Caută";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1835,12 +1787,6 @@ class TranslatorRomanian : public Translator
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Grafic de dependență a directoarelor pentru "+name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
@@ -1953,7 +1899,7 @@ class TranslatorRomanian : public Translator
     virtual QCString trPanelSynchronisationTooltip(bool enable)
     {
       QCString opt = enable ? "activa" : "dezactiva";
-      return "apasă 'click' pentru a "+opt+" sincronizarea panourilor";
+      return "apasă click pentru a "+opt+" sincronizarea panourilor";
     }
 
     /*! Used in a method of an Objective-C class that is declared in a
