@@ -19,7 +19,7 @@
 #ifndef TRANSLATOR_UA_H
 #define TRANSLATOR_UA_H
 
-class TranslatorUkrainian : public TranslatorAdapter_1_8_2
+class TranslatorUkrainian : public TranslatorAdapter_1_8_4
 {
   public:
     /*! Used for identification of the language. */
@@ -32,12 +32,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
       return "\\usepackage[T2A]{fontenc}\n\\usepackage[ukrainian]{babel}\n";
     }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-        return "utf-8";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -366,12 +360,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
     virtual QCString trDefines()
     { return "Макровизначення"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Прототипи фукцій"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -408,12 +396,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
     virtual QCString trDefineDocumentation()
     { return "Опис макровизначень"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Опис прототипів функцій"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -468,12 +450,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
       result+=" системою";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return "Автор:";
-    }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
@@ -757,7 +733,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
         case ClassDef::Exception:
           if (single) result+="цього винятку"; else result+="цих винятків";
           break;
-        default: 
+        default:
           break;
       }
       result+=" була створена з файл";
@@ -765,12 +741,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Алфавітний покажчик"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1068,16 +1038,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
       return "Список тестів";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "DCOP Методи";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1404,14 +1364,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Шукати";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1795,12 +1747,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_2
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Граф залежностей каталогу для "+name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
