@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -105,73 +105,73 @@ void XmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Nbsp:          m_t << "<nonbreakablespace/>"; break;
     case DocSymbol::Aelig:         m_t << "<aelig/>"; break;
     case DocSymbol::AElig:         m_t << "<AElig/>"; break;
-    case DocSymbol::GrkGamma:      m_t << "<Gamma>"; break;
-    case DocSymbol::GrkDelta:      m_t << "<Delta>"; break;
-    case DocSymbol::GrkTheta:      m_t << "<Theta>"; break;
-    case DocSymbol::GrkLambda:     m_t << "<Lambda>"; break;
-    case DocSymbol::GrkXi:         m_t << "<Xi>"; break;
-    case DocSymbol::GrkPi:         m_t << "<Pi>"; break;
-    case DocSymbol::GrkSigma:      m_t << "<Sigma>"; break;
-    case DocSymbol::GrkUpsilon:    m_t << "<Upsilon>"; break;
-    case DocSymbol::GrkPhi:        m_t << "<Phi>"; break;
-    case DocSymbol::GrkPsi:        m_t << "<Psi>"; break;
-    case DocSymbol::GrkOmega:      m_t << "<Omega>"; break;
-    case DocSymbol::Grkalpha:      m_t << "<alpha>"; break;
-    case DocSymbol::Grkbeta:       m_t << "<beta>"; break;
-    case DocSymbol::Grkgamma:      m_t << "<gamma>"; break;
-    case DocSymbol::Grkdelta:      m_t << "<delta>"; break;
-    case DocSymbol::Grkepsilon:    m_t << "<epsilon>"; break;
-    case DocSymbol::Grkzeta:       m_t << "<zeta>"; break;
-    case DocSymbol::Grketa:        m_t << "<eta>"; break;
-    case DocSymbol::Grktheta:      m_t << "<theta>"; break;
-    case DocSymbol::Grkiota:       m_t << "<iota>"; break;
-    case DocSymbol::Grkkappa:      m_t << "<kappa>"; break;
-    case DocSymbol::Grklambda:     m_t << "<lambda>"; break;
-    case DocSymbol::Grkmu:         m_t << "<mu>"; break;
-    case DocSymbol::Grknu:         m_t << "<nu>"; break;
-    case DocSymbol::Grkxi:         m_t << "<xi>"; break;
-    case DocSymbol::Grkpi:         m_t << "<pi>"; break;
-    case DocSymbol::Grkrho:        m_t << "<rho>"; break;
-    case DocSymbol::Grksigma:      m_t << "<sigma>"; break;
-    case DocSymbol::Grktau:        m_t << "<tau>"; break;
-    case DocSymbol::Grkupsilon:    m_t << "<upsilon>"; break;
-    case DocSymbol::Grkphi:        m_t << "<phi>"; break;
-    case DocSymbol::Grkchi:        m_t << "<chi>"; break;
-    case DocSymbol::Grkpsi:        m_t << "<psi>"; break;
-    case DocSymbol::Grkomega:      m_t << "<omega>"; break;
-    case DocSymbol::Grkvarsigma:   m_t << "<sigmaf>"; break;
-    case DocSymbol::Section:       m_t << "<sect>"; break;
-    case DocSymbol::Degree:        m_t << "<deg>"; break;
-    case DocSymbol::Prime:         m_t << "<prime>"; break;
-    case DocSymbol::DoublePrime:   m_t << "<Prime>"; break;
-    case DocSymbol::Infinity:      m_t << "<infin>"; break;
-    case DocSymbol::EmptySet:      m_t << "<empty>"; break;
-    case DocSymbol::PlusMinus:     m_t << "<plusmn>"; break;
-    case DocSymbol::Times:         m_t << "<times>"; break;
-    case DocSymbol::Minus:         m_t << "<minus>"; break;
-    case DocSymbol::CenterDot:     m_t << "<sdot>"; break;
-    case DocSymbol::Partial:       m_t << "<part>"; break;
-    case DocSymbol::Nabla:         m_t << "<nabla>"; break;
-    case DocSymbol::SquareRoot:    m_t << "<radic>"; break;
-    case DocSymbol::Perpendicular: m_t << "<perp>"; break;
-    case DocSymbol::Sum:           m_t << "<sum>"; break;
-    case DocSymbol::Integral:      m_t << "<int>"; break;
-    case DocSymbol::Product:       m_t << "<prod>"; break;
-    case DocSymbol::Similar:       m_t << "<sim>"; break;
-    case DocSymbol::Approx:        m_t << "<asymp>"; break;
-    case DocSymbol::NotEqual:      m_t << "<ne>"; break;
-    case DocSymbol::Equivalent:    m_t << "<equiv>"; break;
-    case DocSymbol::Proportional:  m_t << "<prop>"; break;
-    case DocSymbol::LessEqual:     m_t << "<le>"; break;
-    case DocSymbol::GreaterEqual:  m_t << "<ge>"; break;
-    case DocSymbol::LeftArrow:     m_t << "<larr>"; break;
-    case DocSymbol::RightArrow:    m_t << "<rarr>"; break;
-    case DocSymbol::SetIn:         m_t << "<isin>"; break;
-    case DocSymbol::SetNotIn:      m_t << "<notin>"; break;
-    case DocSymbol::LeftCeil:      m_t << "<lceil>"; break;
-    case DocSymbol::RightCeil:     m_t << "<rceil>"; break;
-    case DocSymbol::LeftFloor:     m_t << "<lfloor>"; break;
-    case DocSymbol::RightFloor:    m_t << "<rfloor>"; break;
+    case DocSymbol::GrkGamma:      m_t << "<Gamma/>"; break;
+    case DocSymbol::GrkDelta:      m_t << "<Delta/>"; break;
+    case DocSymbol::GrkTheta:      m_t << "<Theta/>"; break;
+    case DocSymbol::GrkLambda:     m_t << "<Lambda/>"; break;
+    case DocSymbol::GrkXi:         m_t << "<Xi/>"; break;
+    case DocSymbol::GrkPi:         m_t << "<Pi/>"; break;
+    case DocSymbol::GrkSigma:      m_t << "<Sigma/>"; break;
+    case DocSymbol::GrkUpsilon:    m_t << "<Upsilon/>"; break;
+    case DocSymbol::GrkPhi:        m_t << "<Phi/>"; break;
+    case DocSymbol::GrkPsi:        m_t << "<Psi/>"; break;
+    case DocSymbol::GrkOmega:      m_t << "<Omega/>"; break;
+    case DocSymbol::Grkalpha:      m_t << "<alpha/>"; break;
+    case DocSymbol::Grkbeta:       m_t << "<beta/>"; break;
+    case DocSymbol::Grkgamma:      m_t << "<gamma/>"; break;
+    case DocSymbol::Grkdelta:      m_t << "<delta/>"; break;
+    case DocSymbol::Grkepsilon:    m_t << "<epsilon/>"; break;
+    case DocSymbol::Grkzeta:       m_t << "<zeta/>"; break;
+    case DocSymbol::Grketa:        m_t << "<eta/>"; break;
+    case DocSymbol::Grktheta:      m_t << "<theta/>"; break;
+    case DocSymbol::Grkiota:       m_t << "<iota/>"; break;
+    case DocSymbol::Grkkappa:      m_t << "<kappa/>"; break;
+    case DocSymbol::Grklambda:     m_t << "<lambda/>"; break;
+    case DocSymbol::Grkmu:         m_t << "<mu/>"; break;
+    case DocSymbol::Grknu:         m_t << "<nu/>"; break;
+    case DocSymbol::Grkxi:         m_t << "<xi/>"; break;
+    case DocSymbol::Grkpi:         m_t << "<pi/>"; break;
+    case DocSymbol::Grkrho:        m_t << "<rho/>"; break;
+    case DocSymbol::Grksigma:      m_t << "<sigma/>"; break;
+    case DocSymbol::Grktau:        m_t << "<tau/>"; break;
+    case DocSymbol::Grkupsilon:    m_t << "<upsilon/>"; break;
+    case DocSymbol::Grkphi:        m_t << "<phi/>"; break;
+    case DocSymbol::Grkchi:        m_t << "<chi/>"; break;
+    case DocSymbol::Grkpsi:        m_t << "<psi/>"; break;
+    case DocSymbol::Grkomega:      m_t << "<omega/>"; break;
+    case DocSymbol::Grkvarsigma:   m_t << "<sigmaf/>"; break;
+    case DocSymbol::Section:       m_t << "<sect/>"; break;
+    case DocSymbol::Degree:        m_t << "<deg/>"; break;
+    case DocSymbol::Prime:         m_t << "<prime/>"; break;
+    case DocSymbol::DoublePrime:   m_t << "<Prime/>"; break;
+    case DocSymbol::Infinity:      m_t << "<infin/>"; break;
+    case DocSymbol::EmptySet:      m_t << "<empty/>"; break;
+    case DocSymbol::PlusMinus:     m_t << "<plusmn/>"; break;
+    case DocSymbol::Times:         m_t << "<times/>"; break;
+    case DocSymbol::Minus:         m_t << "<minus/>"; break;
+    case DocSymbol::CenterDot:     m_t << "<sdot/>"; break;
+    case DocSymbol::Partial:       m_t << "<part/>"; break;
+    case DocSymbol::Nabla:         m_t << "<nabla/>"; break;
+    case DocSymbol::SquareRoot:    m_t << "<radic/>"; break;
+    case DocSymbol::Perpendicular: m_t << "<perp/>"; break;
+    case DocSymbol::Sum:           m_t << "<sum/>"; break;
+    case DocSymbol::Integral:      m_t << "<int/>"; break;
+    case DocSymbol::Product:       m_t << "<prod/>"; break;
+    case DocSymbol::Similar:       m_t << "<sim/>"; break;
+    case DocSymbol::Approx:        m_t << "<asymp/>"; break;
+    case DocSymbol::NotEqual:      m_t << "<ne/>"; break;
+    case DocSymbol::Equivalent:    m_t << "<equiv/>"; break;
+    case DocSymbol::Proportional:  m_t << "<prop/>"; break;
+    case DocSymbol::LessEqual:     m_t << "<le/>"; break;
+    case DocSymbol::GreaterEqual:  m_t << "<ge/>"; break;
+    case DocSymbol::LeftArrow:     m_t << "<larr/>"; break;
+    case DocSymbol::RightArrow:    m_t << "<rarr/>"; break;
+    case DocSymbol::SetIn:         m_t << "<isin/>"; break;
+    case DocSymbol::SetNotIn:      m_t << "<notin/>"; break;
+    case DocSymbol::LeftCeil:      m_t << "<lceil/>"; break;
+    case DocSymbol::RightCeil:     m_t << "<rceil/>"; break;
+    case DocSymbol::LeftFloor:     m_t << "<lfloor/>"; break;
+    case DocSymbol::RightFloor:    m_t << "<rfloor/>"; break;
     default:
                              err("unknown symbol found\n");
   }
@@ -246,12 +246,18 @@ void XmlDocVisitor::visit(DocStyleChange *s)
 void XmlDocVisitor::visit(DocVerbatim *s)
 {
   if (m_hide) return;
+  QCString lang = m_langExt;
+  if (!s->language().isEmpty()) // explicit language setting
+  {
+    lang = s->language();
+  }
+  SrcLangExt langExt = getLanguageFromFileName(lang);
   switch(s->type())
   {
     case DocVerbatim::Code: // fall though
       m_t << "<programlisting>"; 
-      Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,s->context(),s->text(),
+      Doxygen::parserManager->getParser(lang)
+                            ->parseCode(m_ci,s->context(),s->text(),langExt,
                                         s->isExample(),s->exampleFile());
       m_t << "</programlisting>"; 
       break;
@@ -310,6 +316,7 @@ void XmlDocVisitor::visit(DocAnchor *anc)
 void XmlDocVisitor::visit(DocInclude *inc)
 {
   if (m_hide) return;
+  SrcLangExt langExt = getLanguageFromFileName(inc->extension());
   switch(inc->type())
   {
     case DocInclude::IncWithLines:
@@ -320,6 +327,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text(),
+                                           langExt,
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
          m_t << "</programlisting>"; 
@@ -330,6 +338,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
       Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),
                                         inc->text(),
+                                        langExt,
                                         inc->isExample(),
                                         inc->exampleFile());
       m_t << "</programlisting>"; 
@@ -352,6 +361,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
                             ->parseCode(m_ci,
                                         inc->context(),
                                         extractBlock(inc->text(),inc->blockId()),
+                                        langExt,
                                         inc->isExample(),
                                         inc->exampleFile()
                                        );
@@ -373,6 +383,7 @@ void XmlDocVisitor::visit(DocIncOperator *op)
     pushEnabled();
     m_hide = TRUE;
   }
+  SrcLangExt langExt = getLanguageFromFileName(m_langExt);
   if (op->type()!=DocIncOperator::Skip) 
   {
     popEnabled();
@@ -380,7 +391,7 @@ void XmlDocVisitor::visit(DocIncOperator *op)
     {
       Doxygen::parserManager->getParser(m_langExt)
                             ->parseCode(m_ci,op->context(),
-                                        op->text(),op->isExample(),
+                                        op->text(),langExt,op->isExample(),
                                         op->exampleFile());
     }
     pushEnabled();
@@ -587,7 +598,7 @@ void XmlDocVisitor::visitPre(DocSection *s)
   if (!s->anchor().isEmpty()) m_t << "_1" << s->anchor();
   m_t << "\">" << endl;
   m_t << "<title>";
-  filter(s->title());
+  filter(convertCharEntitiesToUTF8(s->title()));
   m_t << "</title>" << endl;
 }
 
@@ -825,6 +836,19 @@ void XmlDocVisitor::visitPost(DocMscFile *)
   if (m_hide) return;
   m_t << "</mscfile>" << endl;
 }
+
+void XmlDocVisitor::visitPre(DocDiaFile *df)
+{
+  if (m_hide) return;
+  m_t << "<diafile name=\"" << df->file() << "\">";
+}
+
+void XmlDocVisitor::visitPost(DocDiaFile *)
+{
+  if (m_hide) return;
+  m_t << "</diafile>" << endl;
+}
+
 void XmlDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
@@ -988,6 +1012,7 @@ void XmlDocVisitor::visitPost(DocParamList *)
 void XmlDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
   m_t << "<xrefsect id=\"";
   m_t << x->file() << "_1" << x->anchor();
   m_t << "\">";
@@ -997,9 +1022,10 @@ void XmlDocVisitor::visitPre(DocXRefItem *x)
   m_t << "<xrefdescription>";
 }
 
-void XmlDocVisitor::visitPost(DocXRefItem *)
+void XmlDocVisitor::visitPost(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
   m_t << "</xrefdescription>";
   m_t << "</xrefsect>";
 }
@@ -1057,6 +1083,19 @@ void XmlDocVisitor::visitPost(DocVhdlFlow *)
 {
 }
 
+void XmlDocVisitor::visitPre(DocParBlock *)
+{
+  if (m_hide) return;
+  m_t << "<parblock>";
+}
+
+void XmlDocVisitor::visitPost(DocParBlock *)
+{
+  if (m_hide) return;
+  m_t << "</parblock>";
+}
+
+
 void XmlDocVisitor::filter(const char *str)
 { 
   m_t << convertToXML(str);
